<?php
/*
    Plugin Name: Habu Assistance
    Plugin URI: 
    Description: Assistance plugin for all Habu Assistance.
    Version: 1.1.1
    Author: nsstheme
    Author URI: 
    License: 
    Text Domain: nsstheme
*/

if (!defined('ABSPATH')) {
    exit;
}

/* * ---------------------------------------------------------------
* Including Files
* -------------------------------------------------------------* */

require_once dirname(__FILE__) . '/autoload.php';

class NSS_Assistance{
    public static $_instance;

    public $plugin_name = 'Habu Assistance';
    public $plugin_version = '1.0.1'; 
    public $file = __FILE__;


    public function __construct(){
        add_action('init', array($this, 'nss_load_textdomain'));
        add_action( 'plugins_loaded', array( $this, 'nss_init' ) );
    }

    /* * ---------------------------------------------------------------
    * Init all hooks and others
    * -------------------------------------------------------------* */

    public function nss_init(){
        add_action('admin_enqueue_scripts', array($this, 'nss_admin_enqueue_scripts'));
        add_action('login_enqueue_scripts', array($this, 'nss_wp_login_css'), 10);
        add_action('widgets_init', array($this, 'nss_widgets_init'));
        add_filter( 'use_widgets_block_editor',array($this, '__return_false' ));
       
        $this->kta_taxonomy_and_post_type_caller();
        $this->kta_post_type_caller();
        new NSS_Users_Meta_Hooks();
        
        //check elementor load
        if ( did_action( 'elementor/loaded' ) ) {
            NSS_Elementor::nss_get_instance();
        }
        
        add_action('admin_head', array($this, 'nss_hide_brizy_admin_notice'));
    }

    /* * ---------------------------------------------------------------
    * Disable widget 
    * -------------------------------------------------------------* */
    function __return_false() {
        remove_theme_support( 'widgets-block-editor' );
    }
    /* * ---------------------------------------------------------------
    * Custome Post Taxonomy
    * -------------------------------------------------------------* */

    public function kta_taxonomy_and_post_type_caller(){

        $tmgc_tax = new NSS_Taxonomies('nsstheme');
        $tmgc_tax->nss_inits('folio_cat', 'Category', 'Folio Categories', 'folio');
        
        $tmgc_tax = new NSS_Taxonomies('nsstheme');
        $tmgc_tax->nss_inits('folio_tag', 'Tag', 'Folio Tags', 'folio');
        
    }

    /* * ---------------------------------------------------------------
    * Custome Post Type
    * -------------------------------------------------------------* */

    public function kta_post_type_caller(){
        
        $tmgc_post = new NSS_Custom_Post('nsstheme');
        $tmgc_post->nss_inits('folio', 'Portfolio', 'Portfolios', array('menu_icon' => 'dashicons-portfolio'));

        $tmgc_post = new NSS_Custom_Post('nsstheme');
        $tmgc_post->nss_inits('team', 'Team', 'Teams', array('menu_icon' => 'dashicons-groups'));
        
        $tmgc_block = new NSS_Custom_Post('nsstheme');
        $tmgc_block->nss_inits('blocks', 'Block', 'Blocks', array('menu_icon' => 'dashicons-editor-kitchensink'));
    }

    /* * ---------------------------------------------------------------
    * JS and CSS for Frontend
    * -------------------------------------------------------------* */

    public static function nss_instance(){

        if (!isset(self::$_instance)) {
            self::$_instance = new NSS_Assistance();
        }
        return self::$_instance;

    }

    /* * ---------------------------------------------------------------
    * Load Css For WP Login
    * -------------------------------------------------------------* */

    public function nss_load_textdomain(){
        load_plugin_textdomain('nsstheme', false, dirname(__FILE__) . '/languages');
    }

    /* * ---------------------------------------------------------------
    *  Widget Caller
    * -------------------------------------------------------------* */

    public function nss_widgets_init(){
        register_widget('NSS_Mailchimp_Widgets');
        register_widget('NSS_Contact_Widgets');
        register_widget('NSS_Recentpost_Widgets');
        register_widget('NSS_Ads_Widgets');
    }

    /* * ---------------------------------------------------------------
    * Posttype Caller
    * -------------------------------------------------------------* */

    public function nss_admin_enqueue_scripts(){
        if (function_exists('wp_enqueue_media')) {
            wp_enqueue_media();
        } else {
            wp_enqueue_style('thickbox');
            wp_enqueue_script('media-upload');
            wp_enqueue_script('thickbox');
        }

        wp_enqueue_style('habu-assistance', plugin_dir_url($this->file) . 'assets/css/admin_style.css', false);
        wp_enqueue_script('nsstheme-core', plugin_dir_url($this->file) . 'assets/js/nss_admin.js', false);
        wp_localize_script('habu-assistance', 'habu_ajax', array('ajaxurl' => admin_url('admin-ajax.php')));
    }

    /*======================================================================
    / Set Capabilities
    /=====================================================================*/

    public function nss_wp_login_css()
    {
        wp_enqueue_style('nsstheme-core', plugin_dir_url($this->file) . 'assets/css/login_style.css', false);
    }

    /* * ---------------------------------------------------------------
   * Create Instance
   * -------------------------------------------------------------* */

    public function kta_assign_custom_post_capabilities()
    {
        $roles = array('editor', 'administrator');
        $types = array('footers', 'cheff', 'galleries', 'blocks');

        foreach ($types as $type):
            foreach ($roles as $the_role):
                $role = get_role($the_role);
                $role->add_cap("read");
                $role->add_cap("read_{$type}");
                $role->add_cap("read_private_{$type}s");
                $role->add_cap("edit_{$type}");
                $role->add_cap("edit_{$type}s");
                $role->add_cap("edit_others_{$type}s");
                $role->add_cap("edit_published_{$type}s");
                $role->add_cap("publish_{$type}s");
                $role->add_cap("delete_others_{$type}s");
                $role->add_cap("delete_private_{$type}s");
                $role->add_cap("delete_published_{$type}s");
            endforeach;
        endforeach;
    }

    function nss_hide_brizy_admin_notice() {
      echo '<style>
        .notice.fw-brz-dismiss {display: none;} 
      </style>';
    }
}

NSS_Assistance::nss_instance();