<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Accordion_Widgets extends Widget_Base{
    
    public function get_name() {
        return 'nss-accordion';
    }
    
    public function get_title() {
        return esc_html__( 'Habu Accordion', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-accordion';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label'     => esc_html__( 'Accordion', 'nsstheme' ),
            ]
        );
            $repeater = new \Elementor\Repeater();
                $repeater->add_control(
                        'accr_title',
                        [
                                'label'         => esc_html__( 'Accordion Title', 'nsstheme' ),
                                'type'          => Controls_Manager::TEXT,
                                'default'       => esc_html__('Accordion Title', 'nsstheme'),
                                'label_block'   => true,
                                'placeholder'   => esc_html__('Insert accordion title', 'nsstheme')
                        ]
                );
                $repeater->add_control(
                        'accr_content',
                        [
                                'label'     => esc_html__( 'Accordion Content', 'nsstheme' ),
                                'type'      => Controls_Manager::WYSIWYG,
                                'default'   => esc_html__('Insert accordion content here.'),
                                'placeholder'   => esc_html__('Insert accordion content', 'nsstheme')
                        ]
            );
            $repeater->add_control(
                'accr_active',
                [
                        'label'             => esc_html__( 'Is Active?', 'nsstheme' ),
                        'type'              => Controls_Manager::SWITCHER,
                        'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                        'label_off'         => esc_html__( 'No', 'nsstheme' ),
                        'description'       => esc_html__('Do you want to make this active item?', 'nsstheme'),
                        'return_value'      => 'yes',
                        'default'           => 'no',
                ]
            );
            $this->add_control(
                        'list',
                        [
                                'label'         => esc_html__( 'Accordion Item', 'nsstheme' ),
                                'type'          => Controls_Manager::REPEATER,
                                'fields'        => $repeater->get_controls(),
                                'default'       => [
                                        [
                                                'accr_title'       => esc_html__( '', 'nsstheme' ),
                                                'accr_content'     => esc_html__( '', 'nsstheme' ),
                                                'accr_active'      => esc_html__( '', 'nsstheme' ),

                                        ],
                                ],
                                'title_field' => '{{{ accr_title }}}',
                        ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2',
            [
                'label'     => esc_html__('Accordion Card Style', 'nsstheme'),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                    'ac_card_margin',
                    [
                            'label' => esc_html__( 'Card Margin', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .singleFaq' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Box_Shadow::get_type(),
                    [
                            'name' => 'ac_card_shadow',
                            'label' => esc_html__( 'Card Shadow', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .singleFaq',
                    ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_3',
            [
                'label'     => esc_html__('Card Head Style', 'nsstheme'),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'ac_heading_typography',
                            'label'     => esc_html__( 'Card Heading Typo', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .singleFaq .card-header .btn',
                    ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'ac_icon_typography',
                            'label'     => esc_html__( 'Card Heading Icon Typo', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .singleFaq .card-header .btn:after',
                    ]
            );
            $this->add_responsive_control(
                    'ac_heading_padding',
                    [
                            'label' => esc_html__( 'Card Heading Padding', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .singleFaq .card-header .btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->start_controls_tabs( 'ac_headeing_tabs' );
                $this->start_controls_tab(
                        'ac_head_tab_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'ac_heading_coolor',[
                                'label'     => esc_html__( 'Heading Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .singleFaq .card-header .btn.collapsed' => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'icon_options',
                        [
                                'label'     => esc_html__( 'Heading Icon Color', 'nsstheme' ),
                                'type'      => Controls_Manager::HEADING,
                                'separator' => 'before',
                        ]
                );
                $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                                'name'      => 'heading_i_color',
                                'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                                'types'     => ['gradient'],
                                'selector'  => '{{WRAPPER}} .singleFaq .card-header .btn.collapsed:after',
                        ]
                );
                $this->add_control(
                        'ac_heading_bg',[
                                'label'     => esc_html__( 'Heading BG', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .singleFaq .card-header .btn.collapsed' => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                                'name' => 'heading_border',
                                'label' => esc_html__( 'Heading Border', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .singleFaq .card-header .btn.collapsed',
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'ac_head_tab_active',
                        [
                                'label' => esc_html__( 'Active', 'nsstheme' ),
                        ]
                );
                    $this->add_control(
                            'ac_heading_coolor_act',[
                                    'label'     => esc_html__( 'Heading Color', 'nsstheme' ),
                                    'type'      => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .singleFaq .card-header .btn' => 'color: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_control(
                            'icon_active_options',
                            [
                                    'label'     => esc_html__( 'Heading Icon Color', 'nsstheme' ),
                                    'type'      => Controls_Manager::HEADING,
                                    'separator' => 'before',
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Background::get_type(),
                            [
                                    'name'      => 'heading_active_i_color',
                                    'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                                    'types'     => ['gradient'],
                                    'selector'  => '{{WRAPPER}} .singleFaq .card-header .btn:after',
                            ]
                    );
                    $this->add_control(
                            'ac_heading_bg_act',[
                                    'label'     => esc_html__( 'Heading BG', 'nsstheme' ),
                                    'type'      => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .singleFaq .card-header .btn' => 'background: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Border::get_type(),
                            [
                                    'name' => 'heading_active_border',
                                    'label' => esc_html__( 'Heading Border', 'nsstheme' ),
                                    'selector' => '{{WRAPPER}} .singleFaq .card-header .btn',
                            ]
                    );
                $this->end_controls_tab();
            $this->end_controls_tabs();
        $this->end_controls_section();
        $this->start_controls_section(
            'section_tab_4',
            [
                'label'     => esc_html__('Card Body Style', 'nsstheme'),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'ac_body_typography',
                            'label'     => esc_html__( 'Content Typo', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .singleFaq .card-body',
                    ]
            );
            $this->add_control(
                    'ac_body_color',[
                            'label'     => esc_html__( 'Content Color', 'nsstheme' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .singleFaq .card-body' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Border::get_type(),
                    [
                            'name' => 'ac_body__border',
                            'label' => esc_html__( 'Content Border', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .singleFaq .card-body',
                    ]
            );
            $this->add_responsive_control(
                    'ac_card_body_padding',
                    [
                            'label' => esc_html__( 'Content Padding', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .singleFaq .card-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings       = $this->get_settings_for_display();
        
        $list           = (isset($settings['list']) && !empty($settings['list'])) ? $settings['list'] : array();
        $tabs_id        = uniqid('nss-accordion-');
        if(count($list) > 0):
            ?>
            <div id="<?php echo esc_attr($tabs_id); ?>" class="habufaq">
                <?php 
                    $i = 1;
                    foreach ($list as $key => $item):
                        $accr_title    = (isset($item['accr_title'])) ? $item['accr_title'] : '';
                        $accr_content  = (isset($item['accr_content'])) ? $item['accr_content'] : '';
                        $accr_active   = (isset($item['accr_active'])) ? $item['accr_active'] : 'no';
                        if($accr_title != '' && $accr_content != ''):
                        ?>
                        <div class="singleFaq">
                            <div class="card-header" id="faq_<?php echo esc_attr($tabs_id . '-' . ($key + 1)); ?>">
                                <h5 class="mb-0">
                                    <button class="btn btn-link <?php if($accr_active != 'yes'){ echo 'collapsed'; } ?>" data-toggle="collapse" data-target="#<?php echo esc_attr($tabs_id . '-' . ($key + 1)); ?>" aria-expanded="<?php if($accr_active == 'yes'){ echo 'true'; }else{ echo 'false'; } ?>" aria-controls="<?php echo esc_attr($tabs_id . '-' . ($key + 1)); ?>">
                                        <?php echo wp_kses_post($accr_title); ?>
                                    </button>
                                </h5>
                            </div>
                            <div id="<?php echo esc_attr($tabs_id . '-' . ($key + 1)); ?>" class="collapse <?php if($accr_active == 'yes'){ echo 'show'; } ?>" aria-labelledby="faq_<?php echo esc_attr($tabs_id . '-' . ($key + 1)); ?>" data-parent="#<?php echo esc_attr($tabs_id); ?>">
                                <div class="card-body">
                                    <?php echo do_shortcode($accr_content); ?>
                                </div>
                            </div>
                        </div>
                        <?php
                        $i++;
                        endif;
                    endforeach;
                ?>
            </div>
            <?php
        endif;
    }
    
    protected function _content_template() {
        
    }
}