<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Banner_Widget extends Widget_Base{
    
    public function get_name() {
        return 'nss-banner';
    }
    
    public function get_title() {
        return esc_html__( 'Habu Banner', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-slides';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Banner', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'title', [
                     'label'             => esc_html__('Heading', 'nsstheme'),
                     'type'              => Controls_Manager::TEXTAREA,
                     'label_block'       => true,
                     'default'           => '',
                     'placeholder'       => esc_html__('inser your banner title here.', 'nsstheme'),
                 ]
         );
        $this->add_control(
                'decs', [
                     'label'             => esc_html__('Description', 'nsstheme'),
                     'type'              => Controls_Manager::TEXTAREA,
                     'label_block'       => true,
                     'default'           => '',
                     'placeholder'       => esc_html__('inser your banner description here.', 'nsstheme'),
                 ]
         );
        $this->add_control(
            'button_text', [
                'label'                 => esc_html__( 'Button text', 'nsstheme' ),
                'type'                  => Controls_Manager::TEXT,
                'default'               => esc_html__( 'Contact Us' , 'nsstheme' ),
                'label_block'           => true,
            ]
        );
        $this->add_control(
            'button_url', [
                'label'                 => esc_html__( 'Button url', 'nsstheme' ),
                'type'                  => Controls_Manager::URL,
                'label_block'           => true,
            ]
        );
        $this->add_control(
                'layer_img',
                [
                        'label'         => esc_html__( 'Layer Image', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                        'description'   => esc_html__('image size should be 590x480px.', 'nsstheme'),
                ]
        );
        $this->add_control(
                'video_btn',
                [
                        'label'         => esc_html__( 'Show Video BTN?', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                ]
        );
        $this->add_control(
            'v_btn_url', [
                'label'                 => esc_html__( 'Video BTN Embed Url.', 'nsstheme' ),
                'type'                  => Controls_Manager::TEXT,
                'label_block'           => true,
                'condition'             => ['video_btn' => 'yes'],
            ]
        );
        $this->add_control(
            'water_text', [
                'label'                 => esc_html__( 'Water Text', 'nsstheme' ),
                'type'                  => Controls_Manager::TEXT,
                'default'               => esc_html__( 'Agency' , 'nsstheme' ),
                'label_block'           => true,
            ]
        );
        $this->add_control(
                'show_scroll_down',
                [
                        'label'         => esc_html__( 'Show Scroll Down', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                ]
        );
        $this->add_control(
                'icons',
                [
                        'label'     => esc_html__( 'Icon', 'nsstheme' ),
                        'type'      => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
                'section_name',
                [
                        'label'         => esc_html__( 'Scroll Down ID', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'label_block'   => TRUE,
                        'condition'     => ['show_scroll_down' => 'yes'],
                        'options'       => '',
                        'description'   => esc_html__('insert unique id. and paste id which section you want to scroll down.', 'nsstheme'),
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_shape', [
                'label' => esc_html__( 'Banner Animate Shape', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'shape_4',
                [
                        'label'         => esc_html__( 'Shape 01', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                ]
        );
        $this->add_control(
                'shape_3',
                [
                        'label'         => esc_html__( 'Shape 02', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                ]
        );
        $this->add_control(
                'shape_2',
                [
                        'label'         => esc_html__( 'Shape 03', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                ]
        );
        $this->add_control(
                'shape_1',
                [
                        'label'         => esc_html__( 'Shape 04', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_bg', [
                'label' => esc_html__( 'Banner Area', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'section_background',
                'label'    => esc_html__( 'Background', 'nsstheme' ),
                'types'    => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .banner-style',
            ]
        );
        $this->add_control(
                'bg_options',
                [
                        'label'     => esc_html__( 'Image Oerlay Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'bg_overlay_color',
                        'label'     => esc_html__( 'Overlay Color', 'nsstheme' ),
                        'types'     => [ 'classic', 'gradient', 'video' ],
                        'selector'  => '{{WRAPPER}} .banner-style:after',
                ]
        );
        $this->add_responsive_control(
            'box_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors'  => [
                    '{{WRAPPER}} .banner-style' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    
                ],
            ]
        );
        $this->add_responsive_control(
           'box_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors'  => [
                    '{{WRAPPER}} .banner-style' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    
                ],
            ]
        );
        $this->end_controls_section();

        //Title Style Section
        $this->start_controls_section(
            'section_title_style', [
                'label' => esc_html__( 'Banner Title', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'title_color', [
                'label'     => esc_html__( 'Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .banner-content h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'title_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .banner-content h3',
            ]
        );
        $this->add_responsive_control(
            'title_section_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .banner-content h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'title_section_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .banner-content h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->end_controls_section();

        //Content Style Section
        $this->start_controls_section(
            'section_content_style', [
                'label' => esc_html__( 'Banner Content', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'content_color', [
                'label'     => esc_html__( 'Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .banner-content p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'content_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .banner-content p',
            ]
        );
        $this->add_responsive_control(
            'content_section_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .banner-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'content_section_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .banner-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->end_controls_section();

        //Button Style Section
        $this->start_controls_section(
            'section_button_style',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Label Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .banner-content .habu-btn'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg',
                        [
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .banner-content .habu-btn'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label'     => esc_html__( 'Label Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .banner-content .habu-btn:hover'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_hover_bg',
                        [
                                'label'     => esc_html__( 'BG Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .banner-content .habu-btn:after'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_responsive_control(
                'btn_1_width',
                [
                    'label' => esc_html__( 'Width', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .banner-content .habu-btn' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_height',
                [
                    'label' => esc_html__( 'Height', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 200,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                            '{{WRAPPER}} .banner-content .habu-btn' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .banner-content .habu-btn',
                    ]
            );
            $this->add_responsive_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .banner-content .habu-btn'       => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .banner-content .habu-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .banner-content .habu-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();

        //Layer Image Style
        $this->start_controls_section(
            'section_layer_style', [
                'label' => esc_html__( 'Banner Layer Image', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
                'layer_options',
                [
                        'label'     => esc_html__( 'Image Oerlay Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'overlay_color',
                        'label'     => esc_html__( 'Overlay Color', 'nsstheme' ),
                        'types'     => [ 'classic', 'gradient', 'video' ],
                        'selector'  => '{{WRAPPER}} .layer-thumb:after',
                ]
        );
        $this->add_responsive_control(
                'img_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .layer-thumb' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'img_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .layer-thumb' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'img_width',
                [
                    'label' => esc_html__( 'Image Width', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .layer-thumb img' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
        $this->end_controls_section();

        //Video BTN Style
        $this->start_controls_section(
            'section_video_btn_style', [
                'label' => esc_html__( 'Video BTN Style', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'btn_icon_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .v-layer .popup-video i',
            ]
        );
        $this->add_responsive_control(
            'btn_icon_color', [
                'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .v-layer .popup-video i' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_icon_bg_color', [
                'label'     => esc_html__( 'Icon BG Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .v-layer .popup-video i' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_icon_shape_1_color', [
                'label'     => esc_html__( 'Animate Shape 1 Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .v-layer .popup-video:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_icon_shape_2_color', [
                'label'     => esc_html__( 'Animate Shape 2 Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .v-layer .popup-video:after' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

        //Water Style Section
        $this->start_controls_section(
            'section_water_style', [
                'label' => esc_html__( 'Water Text', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'water_color', [
                'label'     => esc_html__( 'Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .water-text' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'water_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .water-text',
            ]
        );
        $this->add_responsive_control(
            'postion_left',
            [
                'label'      => esc_html__( 'Position Left', 'nsstheme' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range'     => [
                    'px'    => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .water-text' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'postion_top',
            [
                'label'      => esc_html__( 'Position Top', 'nsstheme' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range'     => [
                    'px'    => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .water-text' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        
    }
    
    protected function render() {
        $settings           = $this->get_settings();

        $title              = $settings['title'];
        $decs               = $settings['decs'];
        $button_text        = $settings['button_text'];
        $button_url         = $settings['button_url'];
        $layer_img          = $settings['layer_img']['url'];
        $water_text         = $settings['water_text'];
        $show_scroll_down   = $settings['show_scroll_down'];
        $icons              = $settings['icons'];
        $section_name       = $settings['section_name'];
        $video_btn          = $settings['video_btn'];
        $v_btn_url          = $settings['v_btn_url'];
        
        ?>
        <section class="banner-01 banner-style <?php if($v_btn_url != ''){echo 'b-overlay';} ?>">
            <?php if($settings['shape_4']['url'] != ''): ?>
                <div class="tri-angle">
                    <img src="<?php echo esc_url($settings['shape_4']['url']); ?>" alt="<?php echo esc_attr__('Image','nsstheme'); ?>">
                </div>
            <?php endif; ?>
            <div class="container">
                <div class="row">
                    <div class="col-xl-7 col-lg-6 col-md-12">
                        <div class="banner-content">
                            <?php if($title != ''): ?>
                                <h3 class="animated"><?php echo esc_html($title); ?></h3>
                            <?php endif; ?>
                            <?php if($decs != ''): ?>
                               <p class="animated">
                                    <?php echo habu_kses($decs); ?>
                               </p>
                            <?php endif; ?>
                            <?php if($button_text != ''): ?>
                               <a target="<?php echo esc_attr( $button_url['is_external'] =='on'?'_blank':'_self' ); ?>" class="habu-btn animated" href="<?php echo esc_url($button_url['url']); ?>"><span><?php echo wp_kses_post($button_text); ?></span></a>
                            <?php endif; ?>
                        </div>
                    </div>
                    <?php if($layer_img !=''): ?>
                    <div class="col-xl-5 col-lg-6 col-md-12">
                        <div class="layer-thumb animated <?php if($v_btn_url != ''){echo 'v-layer';} ?>">
                            <img src="<?php echo esc_url($layer_img); ?>" alt="<?php echo esc_attr__('Image','nsstheme'); ?>">
                            <?php if($video_btn == 'yes' && $v_btn_url != ''): ?>
                                <a class="popup-video" href="<?php echo esc_url($v_btn_url); ?>"><i class="flaticon-play"></i></a>
                            <?php endif; ?>
                        </div>
                        <?php if($settings['shape_2']['url'] != ''): ?>
                            <div class="shape_2">
                                <img src="<?php echo esc_url($settings['shape_2']['url']); ?>" alt="<?php echo esc_attr__('Image','nsstheme'); ?>">
                            </div>
                        <?php endif; ?>
                        <?php if($settings['shape_3']['url'] != ''): ?>
                            <div class="shape_3">
                                <img src="<?php echo esc_url($settings['shape_3']['url']); ?>" alt="<?php echo esc_attr__('Image','nsstheme'); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
            <?php if($water_text != ''): ?>
                <div class="water-text animated"><?php echo esc_html($water_text); ?></div>
            <?php endif; ?>
            <?php if($settings['shape_1']['url'] != ''): ?>
                <div class="shape_1">
                    <img src="<?php echo esc_url($settings['shape_1']['url']); ?>" alt="<?php echo esc_attr__('Image','nsstheme'); ?>">
                </div>
            <?php endif; ?>
            <?php if($show_scroll_down == 'yes'): ?>
                <a href="#<?php echo esc_attr($section_name); ?>" class="scrollDown scrollOff">
                    <?php if($icons != ''): ?>
                        <i class="<?php echo esc_attr($icons); ?>"></i>
                    <?php endif; ?>
                </a>
            <?php endif; ?>
        </section>
        <?php
        
    }
    
    protected function _content_template() {
        
    }
}