<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
	exit;

class NSS_Brand_Logo extends Widget_Base{
	
	public function get_name() {
		return 'nss-brand-logo';
	}
	
	public function get_title() {
		return esc_html__( 'Client Logo Slider', 'nsstheme' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'habu-elements' ];
	}
	
	protected function _register_controls() {
		$this->start_controls_section(
			'section_tab',
			[
				'label' => esc_html__('Client Logo', 'nsstheme'),
			]
		);
		$repeater = new \Elementor\Repeater();
			$repeater->add_control(
			   'list_title', [
				  'label' => esc_html__( 'Logo Title', 'nsstheme' ),
				  'type' => \Elementor\Controls_Manager::TEXT,
				  'default' => esc_html__( 'Logo Title' , 'nsstheme' ),
				  'label_block' => true,
			   ]
			);
			$repeater->add_control(
				'client_logo',
				[
						'label'         => esc_html__( 'Client Logo', 'nsstheme' ),
						'type'          => Controls_Manager::MEDIA,
						'description'   => esc_html__('Logo size should be 166x71px.', 'nsstheme'),
				]
			);
			$repeater->add_control(
	                'is_link',
	                [
	                        'label'             => esc_html__( 'Is Link?', 'nsstheme' ),
	                        'type'              => Controls_Manager::SWITCHER,
	                        'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
	                        'label_off'         => esc_html__( 'No', 'nsstheme' ),
	                        'description'       => esc_html__('Do you want to link this title?', 'nsstheme'),
	                        'return_value'      => 'yes',
	                        'default'           => 'no',
	                ]
	        );
			$repeater->add_control(
				'list_url', [
				   'label'          => esc_html__( 'Url', 'nsstheme' ),
				   'type'           => Controls_Manager::TEXT,
                   'condition'   	=> ['is_link' => 'yes'],
				   'default'        => esc_html__( 'Logo Url' , 'nsstheme' ),
				   'label_block'    => true,
				]
			 );
			$this->add_control(
			   'list',
			   [
				  'label'       => esc_html__( 'Logo List', 'nsstheme' ),
				  'type'        => Controls_Manager::REPEATER,
				  'fields'      => $repeater->get_controls(),
				  'title_field' => '{{{ list_title }}}',
			   ]
			);
		$this->add_control(
					'client_slide_autoplay',
					[
							'label'             => esc_html__( 'Is Autoplay?', 'nsstheme' ),
							'type'              => Controls_Manager::SWITCHER,
							'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
							'label_off'         => esc_html__( 'No', 'nsstheme' ),
							'description'       => esc_html__('Do you want to make this slider auto play?', 'nsstheme'),
							'return_value'      => 'yes',
							'default'           => 'yes',
					]
			);
			$this->add_control(
					'client_slide_loop',
					[
							'label'             => esc_html__( 'Is Loop?', 'nsstheme' ),
							'type'              => Controls_Manager::SWITCHER,
							'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
							'label_off'         => esc_html__( 'No', 'nsstheme' ),
							'description'       => esc_html__('Do you want to make this slider item loop?', 'nsstheme'),
							'return_value'      => 'yes',
							'default'           => 'yes',
					]
			);
			 $this->add_control(
					'logo_items',
					[
							'label' => esc_html__( 'Items Item', 'nsstheme' ),
							'type' => Controls_Manager::NUMBER,
							'min' => 1,
							'max' => 10,
							'step' => 1,
							'default' => 4,
							'description'       => esc_html__('Choose how many items you want to show.', 'nsstheme'),
					]
			);
			$this->add_control(
					'items_gapping',
					[
							'label' => esc_html__( 'Items Gapping', 'nsstheme' ),
							'type' => Controls_Manager::NUMBER,
							'min' => 0,
							'max' => 100,
							'step' => 1,
							'default' => 10,
							'description'       => esc_html__('Insert items gapping if you want.', 'nsstheme'),
					]
			);
			$this->add_control(
					'show_grayscale',
					[
							'label'         => esc_html__( 'Is Grayscale?', 'nsstheme' ),
							'type'          => Controls_Manager::SWITCHER,
							'label_on'      => esc_html__( 'Show', 'nsstheme' ),
							'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
							'return_value'  => 'yes',
							'default'       => 'yes',
					]
			);
		$this->end_controls_section();
		
		$this->start_controls_section(
				'section_tab_02', [
					'label'             => esc_html__('Logo Styling', 'nsstheme'),
					'tab'               => Controls_Manager::TAB_STYLE
				]
		);
			$this->start_controls_tabs( 'item_styling_tab' );
				$this->start_controls_tab(
						'item_styling_tab_normal',
						[
								'label' => esc_html__( 'Normal', 'nsstheme' ),
						]
				);
					$this->add_control(
							'cl_item_bg',
							[
									'label' => esc_html__( 'Item BG Color', 'nsstheme' ),
									'type'  => Controls_Manager::COLOR,
									'selectors' => [
											'{{WRAPPER}} .cs_item' => 'background: {{VALUE}}'
									],
							]
					);
					$this->add_group_control(
							Group_Control_Box_Shadow::get_type(),
							[
									'name' => 'cl_item_shadow',
									'label' => esc_html__( 'Boxs Shadow', 'nsstheme' ),
									'selector' => '{{WRAPPER}} .cs_item',
							]
					);
					$this->add_group_control(
							Group_Control_Border::get_type(),
							[
									'name' => 'cl_item_border',
									'label' => esc_html__( 'Border', 'nsstheme' ),
									'selector' => '{{WRAPPER}} .cs_item',
							]
					);
				$this->end_controls_tab();
				$this->start_controls_tab(
						'item_styling_tab_hover',
						[
								'label' => esc_html__( 'Hover', 'nsstheme' ),
						]
				);
					$this->add_control(
							'cl_item_bg_hover',
							[
									'label' => esc_html__( 'Item BG Color', 'nsstheme' ),
									'type'  => Controls_Manager::COLOR,
									'selectors' => [
											'{{WRAPPER}} .cs_item:hover' => 'background: {{VALUE}}'
									],
							]
					);
					$this->add_group_control(
							Group_Control_Box_Shadow::get_type(),
							[
									'name' => 'cl_item_shadow_hover',
									'label' => esc_html__( 'Boxs Shadow', 'nsstheme' ),
									'selector' => '{{WRAPPER}} .cs_item:hover',
							]
					);
					$this->add_group_control(
							Group_Control_Border::get_type(),
							[
									'name' => 'cl_item_border_hover',
									'label' => esc_html__( 'Border', 'nsstheme' ),
									'selector' => '{{WRAPPER}} .cs_item:hover',
							]
					);
				$this->end_controls_tab();
			$this->end_controls_tabs();
			$this->add_control(
					'cl_item_padding',
					[
							'label' => esc_html__( 'Item Padding', 'nsstheme' ),
							'type'  => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors' => [
									'{{WRAPPER}} .cs_item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
							],
					]
			);
			$this->add_control(
					'cl_item_margin',
					[
							'label' => esc_html__( 'Item Margin', 'nsstheme' ),
							'type'  => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors' => [
									'{{WRAPPER}} .cs_item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
							],
					]
			);
			$this->add_responsive_control(
				'img_width',
				[
					'label' => esc_html__( 'Logo Width', 'nsstheme' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [],
					'selectors' => [
						'{{WRAPPER}} .client_sliders.owl-carousel img' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'img_height',
				[
					'label' => esc_html__( 'Logo Height', 'nsstheme' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [],
					'selectors' => [
						'{{WRAPPER}} .client_sliders.owl-carousel img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
		
		
	}
	
	protected function render() {
		$settings       = $this->get_settings_for_display();

		$autoplay       = (isset($settings['client_slide_autoplay']) ? $settings['client_slide_autoplay'] : 'yes');
		$loop           = (isset($settings['client_slide_loop']) ? $settings['client_slide_loop'] : 'yes');
		$logo_items     = (isset($settings['logo_items']) ? $settings['logo_items'] : 4);
		$gapping        = (isset($settings['items_gapping']) ? $settings['items_gapping'] : 10);
		$show_grayscale = $settings['show_grayscale'];
		
		$client         = $settings['list'];
		
		if(!empty($client)): ?>
			<div class="clslider_wrap" 
				 data-autoplay="<?php echo ($autoplay == 'yes' ? '1' : '0'); ?>" 
				 data-loop="<?php echo ($loop == 'yes' ? '1' : '0'); ?>" 
				 data-gapping="<?php echo esc_attr($gapping); ?>" 
				 data-item="<?php echo esc_attr($logo_items); ?>">
				<div class="client_sliders owl-carousel">
					<?php
					foreach($client as $item):
						if($item['client_logo']['url'] != ''):
							?>
							<div class="cs_item <?php if($show_grayscale == 'yes'){echo 'grayscale';} ?>">
								<?php if($item['is_link'] == 'yes'): ?><a href="<?php echo esc_url($item['list_url']); ?>"><?php endif; ?>
									<img src="<?php echo esc_url($item['client_logo']['url']); ?>" alt="<?php echo esc_attr($item['list_title']); ?>">
								<?php if($item['is_link'] == 'yes'): ?></a><?php endif; ?>
							</div>
							<?php
						endif;
					endforeach;
					?>
				</div>
			</div>
			<?php
		endif;    
		
	}
	
	protected function _content_template() {

	}
	
	
}