<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Contcat_Form_Widget extends Widget_Base {

    public function get_name() {
        return 'nss-contact-form';
    }

    public function get_title() {
        return esc_html__( 'Contact From', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        global $wpdb;
        $table = $wpdb->prefix.'posts';
        $result = $wpdb->get_results( 'SELECT * FROM '.$table.' WHERE post_type="wpcf7_contact_form" AND post_status="publish"', OBJECT );
        $shortcodes = array();
        if(is_array($result) && count($result) > 0){
            foreach($result as $r){
                $shortcodes[$r->ID] = $r->post_title;
            }
        }
        $this->start_controls_section(
            'section_tab', [
                'label'     => esc_html__( 'Contact Form', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'contact_form',
                [
                        'label'     => esc_html__( 'Select Form', 'nsstheme' ),
                        'type'      => Controls_Manager::SELECT,
                        'default'   => '',
                        'options'   => $shortcodes,
                ]
        );
        $this->add_responsive_control(
                'form_align', [
                        'label'                     => esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'              => [
                                        'title'     => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-left',
                                ],
                                'center'            => [
                                        'title'     => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-center',
                                ],
                                'right'             => [
                                        'title'     => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'left',
                        'prefix_class'              => 'form_align elementor%s-align-',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2', [
                'label'         => esc_html__( 'Form Field Style', 'nsstheme' ),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'cf_field_typo',
                            'label'     => esc_html__( 'Field Typography', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .contact-form input:not([type="submit"]), {{WRAPPER}} .contact-form select, {{WRAPPER}} .contact-form textarea',
                    ]
            );
            $this->add_control(
                    'cf_text_color',
                    [
                            'label' => esc_html__( 'Text Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input:not([type="submit"])' => 'color: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form select' => 'color: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form textarea' => 'color: {{VALUE}}',
                                
                                    '{{WRAPPER}} .contact-form textarea::-moz-placeholder' => 'color: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form form input::-moz-placeholder' => 'color: {{VALUE}}',
                                
                                    '{{WRAPPER}} .contact-form textarea::-ms-input-placeholder' => 'color: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form form input::-ms-input-placeholder' => 'color: {{VALUE}}',
                                
                                    '{{WRAPPER}} .contact-form textarea::-webkit-input-placeholder' => 'color: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form form input::-webkit-input-placeholder' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_bg_color',
                    [
                            'label' => esc_html__( 'Background Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form select' => 'background: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form input:not([type="submit"])' => 'background: {{VALUE}}',
                                    '{{WRAPPER}} .contact-form textarea' => 'background: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Border::get_type(),
                    [
                            'name' => 'cf_borders',
                            'label' => esc_html__( 'Field Border', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .contact-form select, {{WRAPPER}} .contact-form input:not([type="submit"]), {{WRAPPER}} .contact-form textarea',
                    ]
            );
            $this->add_control(
                    'cf_field_radius',
                    [
                            'label' => esc_html__( 'Field Radius', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input:not([type="submit"])' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form textarea' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Box_Shadow::get_type(),
                    [
                            'name' => 'cf_field_shadow',
                            'label' => esc_html__( 'Field Shadow', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .contact-form select, {{WRAPPER}} .contact-form input:not([type="submit"]), {{WRAPPER}} .contact-form textarea',
                    ]
            );
            $this->add_control(
                    'cf_field_padding',
                    [
                            'label' => esc_html__( 'Field Padding', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input:not([type="submit"])' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_field_margin',
                    [
                            'label' => esc_html__( 'Field Margin', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form select' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input:not([type="submit"])' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form textarea' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_filed_height',
                    [
                            'label' => esc_html__( 'Input/Select Height', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px'],
                            'range' => [
                                    'px' => [
                                            'min' => 0,
                                            'max' => 500,
                                            'step' => 1,
                                    ]
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input[type="text"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input[type="email"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input[type="url"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input[type="tel"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input[type="number"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form input[type="date"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form select' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_message_height',
                    [
                            'label' => esc_html__( 'Textarea Height', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px'],
                            'range' => [
                                    'px' => [
                                            'min' => 0,
                                            'max' => 500,
                                            'step' => 1,
                                    ]
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form textarea' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_3', [
                'label'         => esc_html__( 'Button Style', 'nsstheme' ),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'cf_btn_typo',
                            'label'     => esc_html__( 'BTN Typography', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .contact-form input[type="submit"], {{WRAPPER}} .contact-form button',
                    ]
            );
            $this->start_controls_tabs( 'btn_styling_tab' );
                $this->start_controls_tab(
                        'btn_styling_tab_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                    $this->add_control(
                            'cf_btn_color',
                            [
                                    'label' => esc_html__( 'BTN Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]' => 'color: {{VALUE}}',
                                            '{{WRAPPER}} .contact-form button' => 'color: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_control(
                            'cf_btn_bg_color',
                            [
                                    'label' => esc_html__( 'Background Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]' => 'background: {{VALUE}}',
                                            '{{WRAPPER}} .contact-form button' => 'background: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Border::get_type(),
                            [
                                    'name' => 'cf_btn_borders',
                                    'label' => esc_html__( 'Field Border', 'nsstheme' ),
                                    'selector' => '{{WRAPPER}} .contact-form input[type="submit"], {{WRAPPER}} .contact-form button',
                            ]
                    );
                    $this->add_control(
                            'cf_btn_radius',
                            [
                                    'label' => esc_html__( 'BTN Radius', 'nsstheme' ),
                                    'type'  => Controls_Manager::DIMENSIONS,
                                    'size_units' => [ 'px', '%', 'em' ],
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                            '{{WRAPPER}} .contact-form button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    ],
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Box_Shadow::get_type(),
                            [
                                    'name' => 'cf_btn_shadow',
                                    'label' => esc_html__( 'Field Shadow', 'nsstheme' ),
                                    'selector' => '{{WRAPPER}} .contact-form input[type="submit"], {{WRAPPER}} .contact-form button',
                            ]
                    );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_styling_tab_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                    $this->add_control(
                            'cf_btn_color_hov',
                            [
                                    'label' => esc_html__( 'BTN Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]:hover' => 'color: {{VALUE}}',
                                            '{{WRAPPER}} .contact-form button:hover' => 'color: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_control(
                            'cf_btn_bg_color_hov',
                            [
                                    'label' => esc_html__( 'Background Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]:hover' => 'background: {{VALUE}}',
                                            '{{WRAPPER}} .contact-form button:hover' => 'background: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Border::get_type(),
                            [
                                    'name' => 'cf_btn_borders_hov',
                                    'label' => esc_html__( 'Field Border', 'nsstheme' ),
                                    'selector' => '{{WRAPPER}} .contact-form input[type="submit"]:hover, {{WRAPPER}} .contact-form button:hover',
                            ]
                    );
                    $this->add_control(
                            'cf_btn_radius_hov',
                            [
                                    'label' => esc_html__( 'BTN Radius', 'nsstheme' ),
                                    'type'  => Controls_Manager::DIMENSIONS,
                                    'size_units' => [ 'px', '%', 'em' ],
                                    'selectors' => [
                                            '{{WRAPPER}} .contact-form input[type="submit"]:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                            '{{WRAPPER}} .contact-form button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    ],
                            ]
                    );
                    $this->add_group_control(
                            Group_Control_Box_Shadow::get_type(),
                            [
                                    'name' => 'cf_btn_shadow_hov',
                                    'label' => esc_html__( 'Field Shadow', 'nsstheme' ),
                                    'selector' => '{{WRAPPER}} .contact-form input[type="submit"]:hover, {{WRAPPER}} .contact-form button:hover',
                            ]
                    );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_control(
                    'cf_btn_padding',
                    [
                            'label' => esc_html__( 'BTN Padding', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input[type="submit"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_btn_margin',
                    [
                            'label' => esc_html__( 'BTN Margin', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input[type="submit"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_btn_width',
                    [
                            'label' => esc_html__( 'Button Width', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%'],
                            'range' => [
                                    'px' => [
                                            'min' => 8,
                                            'max' => 3000,
                                            'step' => 5,
                                    ],
                                    '%' => [
                                            'min' => 20,
                                            'max' => 100,
                                            'step' => 1,
                                    ]
                            ],
                            'default' => [
                                    'unit' => '%',
                                    'size' => '',
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input[type="submit"]' => 'width: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form button' => 'width: {{SIZE}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'cf_btn_height',
                    [
                            'label' => esc_html__( 'Button Height', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px'],
                            'range' => [
                                    'px' => [
                                            'min' => 8,
                                            'max' => 300,
                                            'step' => 1,
                                    ]
                            ],
                            'default' => [
                                    'unit' => 'px',
                                    'size' => '',
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .contact-form input[type="submit"]' => 'height: {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .contact-form button' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings       = $this->get_settings();
        $contact_form   = (isset($settings['contact_form']) && $settings['contact_form'] != '') ? $settings['contact_form'] : '';
        
        if($contact_form > 0){
            echo '<div class="contact-form">';
                echo do_shortcode('[contact-form-7 id="'.$contact_form.'"]');
            echo '</div>';
        }else{
            ?>
            <div class="alert alert-warning" role="alert">
                <?php echo esc_html__('Please Select Contact From.', 'nsstheme'); ?>
            </div>
            <?php
        }
        
    }

    protected function _content_template() {

    }    
}