<?php

if (!defined('ABSPATH')) exit;

final class NSS_Elementor
{

    /**
     * Instance
     * @since 1.0.0
     */

    public static $_instance;


    public $file = __FILE__;

    /**
     * Load Construct
     * @since 1.0.0
     */

    public function __construct()
    {
        
        add_action('elementor/controls/controls_registered', array( $this, 'nss_icon_pack' ), 11 );
        
        add_action('elementor/elements/categories_registered', array($this, 'add_widget_categories'));
        add_action('elementor/widgets/widgets_registered', array($this, 'nss_elements'));

        add_action('elementor/editor/after_enqueue_styles', array($this, 'editor_enqueue_styles'));
        add_action('elementor/editor/before_enqueue_scripts', array($this, 'editor_enqueue_scripts'));

        add_action('elementor/frontend/before_enqueue_scripts', array($this, 'frontend_enqueue_scripts'));
        add_action('elementor/frontend/after_enqueue_styles', array($this, 'frontend_enqueue_scripts'));

    }

            
    /**
     * Extend Icon pack core controls.
     *
     * @param  object $controls_manager Controls manager instance.
     * @return void 
    */

    public function nss_icon_pack( $controls_manager ) {

        require_once (dirname($this->file). '/controls/nss-icon.php');
        
        $controls = array(
            $controls_manager::ICON => 'NSS_Icon_Controler',
        );

        foreach ( $controls as $control_id => $class_name ) {
            $controls_manager->unregister_control( $control_id );
            $controls_manager->register_control( $control_id, new $class_name() );
        }

    }
    
    /**
     * Category Register
     * @since  1.0.0
     */

    public function add_widget_categories($elements_manager)
    {
        $elements_manager->add_category(
            'habu-elements',
            [
                'title' => esc_html__('Habu', 'nsstheme'),
                'icon' => 'fa fa-plug',
            ],
            1
        );
    }

    /**
     * Elements register
     * @since  1.0.0
     */

    public function nss_elements($widgets_manager)
    {
        
        require_once dirname($this->file) . '/nss-headings.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Headings_Widget());
        
        require_once dirname($this->file) . '/nss-section-title.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Section_Title_Widget());

        require_once dirname($this->file) . '/nss-banner.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Banner_Widget());

        require_once dirname($this->file) . '/nss-hero-slider.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Hero_Slider_Widget());

        require_once dirname($this->file) . '/nss-icon-box.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Icon_Box());

        require_once dirname($this->file) . '/nss-brand-logo.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Brand_Logo());

        require_once dirname($this->file) . '/nss-service.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Services());

        require_once dirname($this->file) . '/nss-portfolio.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Portfolio());

        require_once dirname($this->file) . '/nss-habu-button.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Habu_Button());

        require_once dirname($this->file) . '/nss-funfact.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Funfact());

        require_once dirname($this->file) . '/nss-listing.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Listing());

        require_once dirname($this->file) . '/nss-post.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Post());

        require_once dirname($this->file) . '/nss-testimonial.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Testimonial());

        require_once dirname($this->file) . '/nss-skills.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Skills_Widgets());

        require_once dirname($this->file) . '/nss-team.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Team_Widgets());

        require_once dirname($this->file) . '/nss-teampost.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Teampost());

        require_once dirname($this->file) . '/nss-pricing.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Pricing_Widgets());

        require_once dirname($this->file) . '/nss-mailchimp-form.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Mailchimp_Form_Widget());

        require_once dirname($this->file) . '/nss-accordion.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Accordion_Widgets());

        require_once dirname($this->file) . '/nss-google-map.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Google_Map_Widget());

        require_once dirname($this->file) . '/nss-contact-form.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Contcat_Form_Widget());

        require_once dirname($this->file) . '/nss-icon.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Icon_Widgets());

        require_once dirname($this->file) . '/nss-vacancy.php';
        $widgets_manager->register_widget_type(new Elementor\NSS_Vacancy_Widgets());
        
        
    }

    /**
     * Frontend enqueue scripts
     * @since  1.0.0
     */

    public function frontend_enqueue_scripts()
    {

    }

    /**
     * Editor enqueue scripts
     * @since  1.0.0
     */

    public function editor_enqueue_scripts()
    {

    }

    /**
     * Editor enqueue styles
     * @since  1.0.0
     */

    public function editor_enqueue_styles()
    {
        wp_enqueue_style( 'nss-icon-elementor', plugins_url('habu-assistance/assets/css/icons.css'), null, '' );
    }

    /**
     * Preview enqueue scripts
     * @since  1.0.0
     */

    public function preview_enqueue_scripts()
    {

    }

    public static function nss_get_instance()
    {
        if (!isset(self::$_instance)) {
            self::$_instance = new NSS_Elementor();
        }
        return self::$_instance;
    }

}