<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Funfact extends Widget_Base{
    
    public function get_name() {
        return 'nss-funfact';
    }
    public function get_title() {
        return esc_html__( 'Funfact', 'nsstheme' );
    }
    public function get_icon() {
        return 'eicon-counter';
    }
    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Funfact', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'icons',
                [
                        'label'         => esc_html__( 'Funfact Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
                'funfact_count',
                [
                        'label'         => esc_html__( 'Count Number', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '3200',
                        'placeholder'   => esc_html__('Count Text', 'nsstheme')
                ]
        );
        $this->add_control(
                'suffix',
                [
                        'label'         => esc_html__( 'Year Suffix', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'description'   => esc_html__( 'Insert suffix for Counter.', 'nsstheme' ),
                        'default'       => esc_html__( '+', 'nsstheme' ),
                ]
        );
        $this->add_control(
                'funfact_title',
                [
                        'label'         => esc_html__( 'Funfact Title', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '',
                        'label_block'   => true,
                        'placeholder'   => esc_html__('Funfact Title', 'nsstheme')
                ]
        );
        $this->add_responsive_control(
                'funfact_align', [
                        'label'                     =>esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'		 => [
                                        'title'	 => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-left',
                                ],
                                'center'	 => [
                                        'title'	 => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-center',
                                ],
                                'right'		 => [
                                        'title'	 => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'center',
                        'prefix_class'              => 'funfact_align elementor%s-align-',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_2',[
                    'label'     => esc_html__('Funfact Area Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'cl_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'cl_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .counter-item-1',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'cl_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .counter-item-1',
                ]
        );
        $this->add_control(
            'box_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .counter-item-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_control(
                'f_1_area_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'f_1_area_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_i_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .counter-item-1 i',
                ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1 i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .counter-item-1 i',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_4',[
                    'label'     => esc_html__('Counter Number Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
         $this->add_control(
                'f_1_count_color',[
                        'label' => esc_html__( 'Count Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1 h3' => 'color: {{VALUE}}',
                        ],
                ]
        );
         $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name' => 'f_1_number_typography',
                        'label' => esc_html__( 'Number Typography', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .counter-item-1 h3',
                ]
        );
        $this->add_control(
                'f_1_count_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .counter-item-1 h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_5',[
                    'label'     => esc_html__('Title Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'f_1_title_color',[
                        'label' => esc_html__( 'Title Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .counter-item-1 p'  => 'color: {{VALUE}}',
                        ],
                ]
        );
         $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name' => 'f_1_title_typography',
                        'label' => esc_html__( 'Title Typography', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .counter-item-1 p',
                ]
        );
        $this->add_control(
                'f_1_title_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .counter-item-1 p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings = $this->get_settings();

        $icons              = (isset($settings['icons']) && $settings['icons'] != '') ? $settings['icons'] : '';
        $funfact_title      = (isset($settings['funfact_title']) && $settings['funfact_title'] != '') ? $settings['funfact_title'] : 'Satisfied Customers';
        $suffix             = (isset($settings['suffix']) && $settings['suffix'] != '' ? $settings['suffix'] : '');
        $funfact_count      = (isset($settings['funfact_count']) && $settings['funfact_count'] != '') ? $settings['funfact_count'] : '3219';
        
        ?>
            <div class="counter-item-1">
                <?php if($icons != ''): ?>
                    <i class="<?php echo esc_attr($icons); ?>"></i>
                <?php endif; ?>
                <?php if($funfact_count != ''): ?>
                <h3><span data-counter="<?php echo esc_attr($funfact_count); ?>" class="timer"><?php echo esc_html($funfact_count); ?></span>
                    <?php echo esc_html($suffix); ?>
                </h3>
                <?php endif; ?>
                <?php if($funfact_title != ''): ?>
                    <p><?php echo habu_kses($funfact_title); ?></p>
                <?php endif; ?>
            </div>
        <?php
         
        
    }
    
    protected function _content_template() {

    }
    
}