<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Google_Map_Widget extends Widget_Base {

    public function get_name() {
        return 'nss-google-map';
    }

    public function get_title() {
        return esc_html__( 'Google Map', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-google-maps';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab', [
                'label' => esc_html__( 'Google Map', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'map_mode',
                [
                        'label'             => esc_html__( 'Map Mode', 'nsstheme' ),
                        'type'              => Controls_Manager::SELECT,
                        'default'           => 1,
                        'label_block'       => true,
                        'options' => [
                                1       => esc_html__( 'Ifram', 'nsstheme' ),
                                2       => esc_html__( 'Custom', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'map_address',
                [
                        'label'             => esc_html__( 'Address', 'nsstheme' ),
                        'type'              => Controls_Manager::TEXTAREA,
                        'label_block'       => true,
                        'default'           => 'London Eye, London, United Kingdom',
                        'placeholder'       => esc_html__( 'Insert a valid address', 'nsstheme' ),
                        'conditions'        => [
                            'terms' => [
                                [
                                        'name'      => 'map_mode',
                                        'operator'  => '!in',
                                        'value'     => ['2'],
                                ]
                            ],
                        ],
                ]
        );
        $this->add_control(
                'grayscale',
                [
                        'label'         => esc_html__( 'Show Grayscale', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                ]
        );
        $this->add_control(
                'lati',
                [
                        'label'             => esc_html__( 'Location Latitude', 'nsstheme' ),
                        'type'              => Controls_Manager::TEXT,
                        'label_block'       => true,
                        'default'           => esc_html__( '52.302101', 'nsstheme' ),
                        'placeholder'       => esc_html__( 'Insert your location latitude', 'nsstheme' ),
                        'condition'         => ['map_mode' => '2']
                ]
        );
        $this->add_control(
                'long',
                [
                        'label'             => esc_html__( 'Location Longitude', 'nsstheme' ),
                        'type'              => Controls_Manager::TEXT,
                        'label_block'       => true,
                        'default'           => esc_html__( '1.294480', 'nsstheme' ),
                        'placeholder'       => esc_html__( 'Insert your location longitude', 'nsstheme' ),
                        'condition'         => ['map_mode' => '2']
                ]
        );
        $this->add_control(
                'map_zoom',
                [
                        'label'         => esc_html__( 'Zoom', 'nsstheme' ),
                        'type'          => Controls_Manager::NUMBER,
                        'min'           => 1,
                        'max'           => 50,
                        'step'          => 1,
                        'default'       => 10
                ]
        );
        $this->add_control(
                'marker',
                [
                        'label'         => esc_html__( 'Map Marker', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                        'description'   => esc_html__('Upload your map marker. Map marker shold be smallar image.', 'nsstheme'),
                        'condition'     => ['map_mode' => '2'],
                ]
        );
        $this->add_responsive_control(
                'map_height',
                [
                        'label'         => esc_html__( 'Map Height', 'nsstheme' ),
                        'type'          => Controls_Manager::SLIDER,
                        'size_units'    => [ 'px', '%' ],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 2000,
                                        'step' => 1,
                                ],
                                '%' => [
                                        'min' => 0,
                                        'max' => 100,
                                ],
                        ],
                        'description'   => esc_html__('Insert your map height. Default height is 600px.', 'nsstheme'),
                        'default'       => ['560'],
                        'selectors'     => [
                                '{{WRAPPER}} .habu_map_two' => 'height: {{SIZE}}{{UNIT}};',
                                '{{WRAPPER}} .habu_map iframe' => 'height: {{SIZE}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings   = $this->get_settings();
        $map_mode   = (isset($settings['map_mode']) && $settings['map_mode'] > 0) ? $settings['map_mode'] : 0;
        $map_address= (isset($settings['map_address']) && $settings['map_address'] != '') ? $settings['map_address'] : '1 Grafton Street, Dublin, Ireland';
        $lati       = (isset($settings['lati']) && $settings['lati'] != '') ? $settings['lati'] : '';
        $long       = (isset($settings['long']) && $settings['long'] != '') ? $settings['long'] : '';
        $zoom       = (isset($settings['map_zoom']) && $settings['map_zoom'] > 0) ? $settings['map_zoom'] : '16';
        $marker     = (isset($settings['marker']['url']) && $settings['marker']['url'] != '') ? $settings['marker']['url'] : '';
        $grayscale  = (isset($settings['grayscale']) && $settings['grayscale'] != '') ? $settings['grayscale'] : '';
        
        if($map_mode == 1 && $map_address != ''):
            $frame = 'https://maps.google.com/maps?q='.urlencode($map_address).'&t=&z='.$zoom.'&ie=UTF8&iwloc=&output=embed';
            ?><div class="habu_map <?php if($grayscale == 'yes'){echo 'grayscale';} ?>"><iframe src="<?php echo esc_url($frame); ?>"></iframe></div><?php   
        elseif($map_mode == 1 && $lati != '' || $long != ''):
            $maps_id        = uniqid('gmap_');
            ?><div data-map-style="<?php if($grayscale == 'yes'){echo 2;}else{echo 1;} ?>" data-marker="<?php echo esc_url($marker); ?>" data-lat="<?php echo esc_attr($lati); ?>" data-lon="<?php echo esc_attr($long); ?>" data-zoom="<?php echo esc_attr($zoom); ?>" class="habu_map_two" id="<?php echo esc_attr($maps_id); ?>"></div><?php
        else:
           ?>
            <div class="alert alert-warning" role="alert">
                <?php echo esc_html__('Please Select Map Style and fill up all related fields.', 'nsstheme'); ?>
            </div>
           <?php
        endif;
    }
    
    protected function _content_template() {
        
    }
}