<?php

namespace Elementor;

if( !defined('ABSPATH') )
    exit;

class NSS_Habu_Button extends Widget_Base{
    
    public function get_name() {
        return 'nss-habu-button';
    }
    public function get_title() {
        return esc_html__( 'Habu Button', 'nsstheme' );
    }
    public function get_icon() {
        return 'eicon-button';
    }
    public function get_categories() {
        return ['habu-elements'];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
                'section_tab', [
                    'label'     => esc_html__('Button ', 'nsstheme')
                ]
        );
            $this->add_control(
                   'btn_label', [
                        'label'             => esc_html__('Button Label', 'nsstheme'),
                        'type'              => Controls_Manager::TEXT,
                        'label_block'       => true,
                        'default'           => '',
                        'placeholder'       => esc_html__('Inser Button Label', 'nsstheme'),
                    ]
            );
            $this->add_control(
                    'btn_icons',
                    [
                            'label'         => esc_html__( 'Button Icon', 'nsstheme' ),
                            'type'          => Controls_Manager::ICON,
                            'label_block'   => TRUE,
                    ]
            );
            $this->add_control(
                    'btn_url', [
                        'label'             => esc_html__( 'URL', 'nsstheme' ),
                        'type'              => Controls_Manager::URL,
                        'input_type'        => 'url',
                        'placeholder'       => esc_html__( 'https://your-link.com', 'nsstheme' ),
                        'show_external'     => true,
                        'default'           => [
                                'url'            => '',
                                'is_external'    => true,
                                'nofollow'       => true,
                        ],
                    ]
            );
            $this->add_responsive_control(
                    'btn_align', [
                            'label'                     => esc_html__( 'Alignment', 'nsstheme' ),
                            'type'                      => Controls_Manager::CHOOSE,
                            'options'                   => [
                                    'left'		 => [
                                            'title'	 => esc_html__( 'Left', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-left',
                                    ],
                                    'center'	 => [
                                            'title'	 => esc_html__( 'Center', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-center',
                                    ],
                                    'right'		 => [
                                            'title'	 => esc_html__( 'Right', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-right',
                                    ]
                            ],
                            'default'                   => 'center',
                            'prefix_class'              => 'btn_align elementor%s-align-',
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Label Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .habu-btn'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg',
                        [
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .habu-btn'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label'     => esc_html__( 'Label Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .habu-btn:hover'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_hover_bg',
                        [
                                'label'     => esc_html__( 'BG Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .habu-btn:after'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_control(
			'btn_1_width',
			[
				'label' => esc_html__( 'Width', 'nsstheme' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [],
				'selectors' => [
					'{{WRAPPER}} .habu-btn' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_control(
			'btn_1_height',
			[
				'label' => esc_html__( 'Height', 'nsstheme' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [],
				'selectors' => [
                    '{{WRAPPER}} .habu-btn' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .habu-btn',
                    ]
            );
            $this->add_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                '{{WRAPPER}} .habu-btn:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Btn Icon Style', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_control(
                'btn_1_icon_color',
                [
                        'label' => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn i'   => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_control(
                'btn_1_icon_hover_color',
                [
                        'label' => esc_html__( 'Icon Hover Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn:hover i'   => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name' => 'btn_2_typography',
                        'label' => esc_html__( 'Icon Typography', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .habu-btn i',
                ]
        );
        $this->add_control(
                'btn_2_padding',
                [
                        'label' => esc_html__( 'Icon Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_2 i_margin',
                [
                        'label' => esc_html__( 'Icon Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .habu-btn i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings       = $this->get_settings();
        $btn_label      = (isset($settings['btn_label']) && $settings['btn_label'] != '') ? $settings['btn_label'] : esc_html__('Button Label', 'nsstheme');
        $icons          = (isset($settings['btn_icons']) && $settings['btn_icons'] != '') ? $settings['btn_icons'] : '';
        
        $target         = $settings['btn_url']['is_external'] ? ' target="_blank"' : '' ;
        $nofollow       = $settings['btn_url']['nofollow'] ? ' rel="nofollow"' : '' ;
        $btn_url        = (isset($settings['btn_url']['url']) && $settings['btn_url']['url'] != '') ? $settings['btn_url']['url'] : '#';
        
        ?>
        <a href="<?php echo esc_url($btn_url); ?>" class="habu-btn" <?php echo esc_attr($target.' '.$nofollow); ?>>
            <span>
                <?php echo esc_html($btn_label); ?>
                <?php if($icons != ''): ?><i class="<?php echo esc_attr($icons); ?>"></i><?php endif; ?>
            </span>
        </a>
        <?php
    }
    
    protected function _content_template() {
        
    }
            
}