<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Headings_Widget extends Widget_Base {
    public function get_name() {
        return 'nss-heading';
    }
    public function get_title() {
        return esc_html__('Headings', 'nsstheme');
    }
    public function get_icon() {
        return 'eicon-heading';
    }
    public function get_categories() {
        return ['habu-elements'];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab', [
                'label'         => esc_html__( 'Heading', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'heading_tag',
                [
                        'label' => esc_html__( 'Tag', 'nsstheme' ),
                        'type' => Controls_Manager::SELECT,
                        'description'   => esc_html__('Select HTML tag that you want to use.', 'nsstheme'),
                        'default' => '2',
                        'options' => [
                                '1'  => esc_html__( 'H1', 'nsstheme' ),
                                '2' => esc_html__( 'H2', 'nsstheme' ),
                                '3' => esc_html__( 'H3', 'nsstheme' ),
                                '4' => esc_html__( 'H4', 'nsstheme' ),
                                '5' => esc_html__( 'H5', 'nsstheme' ),
                                '6' => esc_html__( 'H6', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'heading_text', [
                    'label'             => esc_html__('Heading Text', 'nsstheme'),
                    'type'              => Controls_Manager::TEXT,
                    'label_block'       => TRUE,
                    'default'           => esc_html__('Add Text', 'nsstheme')
                ]
        );
        $this->add_responsive_control(
                'heading_alignment', [
                        'label'                     => esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'              => [
                                        'title'     => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-left',
                                ],
                                'center'            => [
                                        'title'     => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-center',
                                ],
                                'right'             => [
                                        'title'     => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'left',
                        'prefix_class'              => 'habu_heading elementor%s-align-',
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_1', [
                'label'         => esc_html__( 'Heading', 'nsstheme' ),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
                'heading_color', [
                        'label'		 => esc_html__( 'Color', 'nsstheme' ),
                        'type'		 => Controls_Manager::COLOR,
                        'selectors'	 => [
                            '{{WRAPPER}} .habu_heading' => 'color: {{VALUE}};'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'heading_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .habu_heading',
                ]
        );
        $this->add_responsive_control(
                'heading_margin',
                [
                        'label' => esc_html__( 'Marigns', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .habu_heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings           = $this->get_settings();
        $heading_tag        = (isset($settings['heading_tag']));
        $heading_text       = (isset($settings['heading_text']) && $settings['heading_text'] !='') ? $settings['heading_text'] : esc_html__('Add Heading', 'nsstheme');
        
        if($heading_text != ''): ?>
            <h<?php echo $heading_tag; ?> class="habu_heading"><?php echo esc_html($heading_text); ?></h<?php echo $heading_tag; ?>>
        <?php endif;
    }
    
    protected function _content_template() {
        
    }
}