<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Hero_Slider_Widget extends Widget_Base{
    
    public function get_name() {
        return 'nss-hero-slider';
    }
    
    public function get_title() {
        return esc_html__( 'Hero Slider', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-slider-push';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Slider Content', 'nsstheme' ),
            ]
        );

        $repeater = new Repeater();
        $repeater->add_control(
                'layer_img',
                [
                        'label'         => esc_html__( 'Backgound Image', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                        'description'   => esc_html__('image size should be 1920x1080px.', 'nsstheme'),
                ]
        );
        $repeater->add_control(
                'video_btn',
                [
                        'label'         => esc_html__( 'Show Video BTN?', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                ]
        );
        $repeater->add_control(
            'v_btn_url', [
                'label'                 => esc_html__( 'Video BTN Embed Url.', 'nsstheme' ),
                'type'                  => Controls_Manager::TEXT,
                'default'           	=> esc_html__('https://www.youtube.com/embed/REwrstu7L_g', 'nsstheme'),
                'label_block'           => true,
                'condition'     		=> ['video_btn' => 'yes'],
            ]
        );
        $repeater->add_control(
                'title', [
                     'label'             => esc_html__('Heading', 'nsstheme'),
                     'type'              => Controls_Manager::TEXTAREA,
                     'label_block'       => true,
                     'default'           => '',
                     'placeholder'       => esc_html__('inser your slider title here.', 'nsstheme'),
                 ]
         );
        $repeater->add_control(
                'decs', [
                     'label'             => esc_html__('Description', 'nsstheme'),
                     'type'              => Controls_Manager::TEXTAREA,
                     'label_block'       => true,
                     'default'           => '',
                     'placeholder'       => esc_html__('inser your slider description here.', 'nsstheme'),
                 ]
         );
        $repeater->add_control(
            'button_text', [
                'label'                 => esc_html__( 'Button text', 'nsstheme' ),
                'type'                  => Controls_Manager::TEXT,
                'default'               => esc_html__( 'Contact Us' , 'nsstheme' ),
                'label_block'           => true,
            ]
        );
        $repeater->add_control(
            'button_url', [
                'label'                 => esc_html__( 'Button url', 'nsstheme' ),
                'type'                  => Controls_Manager::URL,
                'label_block'           => true,
            ]
        );
        $repeater->add_responsive_control(
            'content_align', [
                'label'   => esc_html__( 'Alignment', 'nsstheme' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                'left'       => [
                    
                    'title' => esc_html__( 'Left', 'nsstheme' ),
                    'icon'  => 'fa fa-align-left',
                ],
                    'center'         => [
                    'title' => esc_html__( 'Center', 'nsstheme' ),
                    'icon'  => 'fa fa-align-center',
                ],
                'right'  => [
                        'title' => esc_html__( 'Right', 'nsstheme' ),
                        'icon'  => 'fa fa-align-right',
                ],
                'justify'    => [

                        'title' => esc_html__( 'Justified', 'nsstheme' ),
                        'icon'  => 'fa fa-align-justify',
                
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .slider-content'   => 'text-align: {{VALUE}};',
                 
                ],
            ]
        );
        $this->add_control(
            'content_list',
            [
                    'label'         => esc_html__( 'Slider Content', 'nsstheme' ),
                    'type'          => Controls_Manager::REPEATER,
                    'fields'        => $repeater->get_controls(),
                    'default'       => [
                            [
                                    'layer_img'         => '',
                                    'video_btn'         => '',
                                    'v_btn_url'         => '',
                                    'title'             => '',
                                    'decs'     			=> '',
                                    'button_text'       => '',
                                    'button_url'        => '',
                                    'content_align'     => '',

                            ],
                    ],
                    'title_field' => '{{{ title }}}',
            ]
        );
        $this->add_control(
                'show_scroll_down',
                [
                        'label'         => esc_html__( 'Show Scroll Down', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                ]
        );
        $this->add_control(
                'icons',
                [
                        'label'     => esc_html__( 'Icon', 'nsstheme' ),
                        'type'      => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
                'section_name',
                [
                        'label'         => esc_html__( 'Scroll Down ID', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'label_block'   => TRUE,
                        'condition'     => ['show_scroll_down' => 'yes'],
                        'options'       => '',
                        'description'   => esc_html__('insert unique id. and paste id which section you want to scroll down.', 'nsstheme'),
                ]
        );
        $this->add_control(
                'animation_show',
                [
                        'label'         => esc_html__( 'Show Slider Image Animation?', 'nsstheme' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'     => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'  => 'yes',
                        'default'       => 'yes',
                ]
        );
        $this->add_control(
                    'slide_autoplay',
                    [
                            'label'             => esc_html__( 'Is Autoplay?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to make this slider auto play?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
            $this->add_control(
                    'slide_loop',
                    [
                            'label'             => esc_html__( 'Is Loop?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to make this slider item loop?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
            $this->add_control(
                    'slide_nav',
                    [
                            'label'             => esc_html__( 'Is Nav?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to show slider arrow navigation?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
            $this->add_control(
                    'slide_dot',
                    [
                            'label'             => esc_html__( 'Is Dots?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to show slider Dots navigation?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_bg', [
                'label' => esc_html__( 'Slider Area', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
                'slider_height',
                [
                        'label' => esc_html__( 'Slider Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 2000,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .bg-img' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'bg_options',
                [
                        'label'     => esc_html__( 'Image Oerlay Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'bg_overlay_color',
                        'label'     => esc_html__( 'Overlay Color', 'nsstheme' ),
                        'types'     => [ 'classic', 'gradient', 'video' ],
                        'selector'  => '{{WRAPPER}} .hero-slider .bg-img:after',
                ]
        );
        $this->add_responsive_control(
        	'box_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors'  => [
                    '{{WRAPPER}} .hero-slider .bg-img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    
                ],
            ]
        );
        $this->add_responsive_control(
           'box_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors'  => [
                    '{{WRAPPER}} .hero-slider .bg-img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    
                ],
            ]
        );
        $this->end_controls_section();

        //Video BTN Style
        $this->start_controls_section(
            'section_video_btn_style', [
                'label' => esc_html__( 'Video BTN Style', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'btn_icon_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .slider-content .popup-video i',
            ]
        );
        $this->add_responsive_control(
            'btn_icon_color', [
                'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .slider-content .popup-video i' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_icon_bg_color', [
                'label'     => esc_html__( 'Icon BG Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .slider-content .popup-video i' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
                'v_width_height',
                [
                        'label' => esc_html__( 'BTN Width', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .slider-content .popup-video' => 'width: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'v_btn_height',
                [
                        'label' => esc_html__( 'BTN Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .slider-content .popup-video' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_responsive_control(
        	'v_btn_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','%'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-content .popup-video' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    
                ],
            ]
        );
        $this->add_responsive_control(
	           'v_btn_padding',
	            [
	                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
	                'type'       => Controls_Manager::DIMENSIONS,
	                'size_units' => [ 'px','%'],
	                'selectors'  => [
	                    '{{WRAPPER}} .slider-content .popup-video i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    
	                ],
	            ]
        );
        $this->add_responsive_control(
            'btn_icon_shape_1_color', [
                'label'     => esc_html__( 'Animate Shape Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .slider-content .popup-video:after' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

        //Title Style Section
        $this->start_controls_section(
            'section_title_style', [
                'label' => esc_html__( 'Banner Title', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'title_color', [
                'label'     => esc_html__( 'Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .slider-content h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'title_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .slider-content h3',
            ]
        );
        $this->add_responsive_control(
            'title_section_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-content h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'title_section_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-content h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->end_controls_section();

        //Content Style Section
        $this->start_controls_section(
            'section_content_style', [
                'label' => esc_html__( 'Banner Content', 'nsstheme' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'content_color', [
                'label'     => esc_html__( 'Color', 'nsstheme' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                '{{WRAPPER}} .slider-content p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                    'name'      => 'content_typho',
                    'label'     => esc_html__( 'Typography', 'nsstheme' ),
                    'selector'  => '{{WRAPPER}} .slider-content p',
            ]
        );
        $this->add_responsive_control(
            'content_section_padding',
            [
                'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'content_section_margin',
            [
                'label'      => esc_html__( 'Margins', 'nsstheme' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->end_controls_section();

        //Button Style Section
        $this->start_controls_section(
            'section_button_style',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Label Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .slider-content .habu-btn'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg',
                        [
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .slider-content .habu-btn'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label'     => esc_html__( 'Label Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .slider-content .habu-btn:hover'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_hover_bg',
                        [
                                'label'     => esc_html__( 'BG Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .slider-content .habu-btn:after'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_responsive_control(
                'btn_1_width',
                [
                    'label' => esc_html__( 'Width', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .slider-content .habu-btn' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_height',
                [
                    'label' => esc_html__( 'Height', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 200,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                            '{{WRAPPER}} .slider-content .habu-btn' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .slider-content .habu-btn',
                    ]
            );
            $this->add_responsive_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .slider-content .habu-btn'   => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .slider-content .habu-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .slider-content .habu-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_07', [
                    'label'             => esc_html__('Nav Arrow Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->start_controls_tabs( 'nav_styling_tab' );
            $this->start_controls_tab(
                    'nav_styling_tab_normal',
                    [
                            'label' => esc_html__( 'Normal', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'tst_nav_color',
                    [
                            'label' => esc_html__( 'Nav Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'color: {{VALUE}}'
                            ],
                    ]
            );
            $this->add_control(
                    'tst_nav_bg',
                    [
                            'label' => esc_html__( 'Nav BG Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'background: {{VALUE}}'
                            ],
                    ]
            );
        $this->end_controls_tab();
        $this->start_controls_tab(
                'nav_styling_tab_hover',
                [
                        'label' => esc_html__( 'Hover', 'nsstheme' ),
                ]
        );
        $this->add_control(
                'tst_nav_color_hover',
                [
                        'label' => esc_html__( 'Nav Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button:hover' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'tst_nav_bg_hover',
                [
                        'label' => esc_html__( 'Nav BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button:hover' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->end_controls_tab();
    $this->end_controls_tabs();
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'tst_nav_bg_shadow',
                        'label' => esc_html__( 'Boxs Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'tst_nav_bg_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button',
                ]
        );
        $this->add_control(
                'nav_width',
                [
                        'label' => esc_html__( 'Nav Width', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'width: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'nav_height',
                [
                        'label' => esc_html__( 'Nav Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'nav_margin',
                [
                        'label' => esc_html__( 'Nav Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'nav_padding',
                [
                        'label' => esc_html__( 'Nav Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider.owl-carousel .owl-nav button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_08', [
                    'label'             => esc_html__('Dots Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                'dots_bg',
                [
                        'label' => esc_html__( 'Dots BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .owl-dots button' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'dots_hover_bg',
                [
                        'label' => esc_html__( 'Dots Hover BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .owl-dots button:hover' => 'background: {{VALUE}}',
                                '{{WRAPPER}} .hero-slider .owl-dots button.active' => 'background: {{VALUE}}',
                        ],
                ]
        );
        $this->add_control(
            'dots_img_radius',
            [
                    'label'      => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'       => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors'  => [
                            '{{WRAPPER}} .hero-slider .owl-dots button'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
            ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'tst_dots_bg_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .hero-slider .owl-dots button',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'tst_dots_bg_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .hero-slider .owl-dots button',
                ]
        );
        $this->add_control(
                'dots_width',
                [
                        'label' => esc_html__( 'Dots Width', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .owl-dots button' => 'width: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'dots_height',
                [
                        'label' => esc_html__( 'Dots Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 500,
                                        'step' => 1,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .owl-dots button' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'dots_margin',
                [
                        'label' => esc_html__( 'Dots Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .hero-slider .owl-dots button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();
        
        
    }
    
    protected function render() {
        $settings           = $this->get_settings();

        $testi_style    = (isset($settings['content_list']) && !empty($settings['content_list'])) ? $settings['content_list'] : array();
        
        $autoplay = (isset($settings['slide_autoplay']) && $settings['slide_autoplay'] != '' ? $settings['slide_autoplay'] : 'yes');
        $loop = (isset($settings['slide_loop']) && $settings['slide_loop'] != '' ? $settings['slide_loop'] : 'yes');
        $nav = (isset($settings['slide_nav']) ? $settings['slide_nav'] : 'yes');
        $dot = (isset($settings['slide_dot']) ? $settings['slide_dot'] : 'yes');

        $animation_show = (isset($settings['animation_show']) ? $settings['animation_show'] : 'yes');
        $anim_class = '';
        if($animation_show == 'yes'){
            $anim_class .= 'anim_class';
        }
        $show_scroll_down   = $settings['show_scroll_down'];
        $icons              = $settings['icons'];
        $section_name       = $settings['section_name'];
        
        ?>
        <section class="hero-section"
        	data-autoplay="<?php echo ($autoplay == 'yes' ? '1' : '0'); ?>" 
            data-loop="<?php echo ($loop == 'yes' ? '1' : '0'); ?>" 
            data-nav="<?php echo ($nav == 'yes' ? '1' : '0'); ?>" 
            data-dots="<?php echo ($dot == 'yes' ? '1' : '0'); ?>" 
            >
        	<div class="hero-slider owl-carousel <?php echo esc_attr($anim_class); ?>">
        		<?php 
                if(!empty($testi_style)):
                    foreach($testi_style as $si):
                        $title              = $si['title'];
				        $decs               = $si['decs'];
				        $button_text        = $si['button_text'];
				        $button_url         = $si['button_url'];
				        $layer_img          = $si['layer_img']['url'];
				        $video_btn          = $si['video_btn'];
				        $v_btn_url          = $si['v_btn_url'];
                ?>
		        <div class="single-slide bg-img d-flex align-items-center" <?php if($layer_img !=''): ?>data-bg-image="<?php echo esc_url($layer_img); ?>"<?php endif; ?>>
		            <div class="container">
		                <div class="row">
		                    <div class="col-lg-12">
		                        <div class="slider-content">
		                        	<?php if($video_btn == 'yes' && $v_btn_url != ''): ?>
		                                <a class="popup-video animated" href="<?php echo esc_url($v_btn_url); ?>"><i class="flaticon-play"></i></a>
		                            <?php endif; ?>
		                            <?php if($title != ''): ?>
		                                <h3 class="animated"><?php echo habu_kses($title); ?></h3>
		                            <?php endif; ?>
		                            <?php if($decs != ''): ?>
		                               <p class="animated">
		                                    <?php echo habu_kses($decs); ?>
		                               </p>
		                            <?php endif; ?>
		                            <?php if($button_text != ''): ?>
		                               <a target="<?php echo esc_attr( $button_url['is_external'] =='on'?'_blank':'_self' ); ?>" class="habu-btn animated" href="<?php echo esc_url($button_url['url']); ?>"><span><?php echo wp_kses_post($button_text); ?></span></a>
		                            <?php endif; ?>
		                        </div>
		                    </div>
		                </div>
		            </div>
		        </div>
		        <?php
            	endforeach;
		        endif;
		    ?>
		    </div>
            <?php if($show_scroll_down == 'yes'): ?>
                <a href="#<?php echo esc_attr($section_name); ?>" class="scrollDown scrollOff">
                    <?php if($icons != ''): ?>
                        <i class="<?php echo esc_attr($icons); ?>"></i>
                    <?php endif; ?>
                </a>
            <?php endif; ?>
        </section>
        <?php
        
    }
    
    protected function _content_template() {
        
    }
}