<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Icon_Widgets extends Widget_Base{
    
    public function get_name() {
        return 'nss-icon';
    }
    
    public function get_title() {
        return esc_html__( 'Single Icon', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-favorite';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab', [
                'label' => esc_html__( 'Icon', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'icons',
                [
                        'label'     => esc_html__( 'Icons', 'nsstheme' ),
                        'type'      => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_responsive_control(
                'box_alignment', [
                        'label'                     =>esc_html__( 'Box Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'		 => [
                                        'title'	 =>esc_html__( 'Left', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-left',
                                ],
                                'center'	 => [
                                        'title'	 =>esc_html__( 'Center', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-center',
                                ],
                                'right'		 => [
                                        'title'	 =>esc_html__( 'Right', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'center',
                        'prefix_class'              => 'icon_holder elementor%s-align-',
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_2',[
                    'label'         => esc_html__('Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name' => 'icon_box_bg',
                        'label' => esc_html__( 'Box Background', 'nsstheme' ),
                        'types' => [ 'classic', 'gradient'],
                        'selector' => '{{WRAPPER}} .icon-single',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_i_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .icon-single i',
                ]
        );
        $this->add_responsive_control(
                'icon_pading',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .icon-single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .icon-single' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .icon-single i',
                ]
        );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings   = $this->get_settings();

        $icons       = $settings['icons'];
        
        $classes = '';
        if($icons != ''){ ?>
            <div class="icon-single"><i class="<?php echo esc_attr($icons); ?>"></i></div>
        <?php }
        
    }
    
    protected function _content_template() {

    }
    
    
}