<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Listing extends Widget_Base {

    public function get_name() {
        return 'nss-listing';
    }

    public function get_title() {
        return esc_html__( 'Habu Listing Item', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-bullet-list';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label'     => esc_html__( 'Listing Item', 'nsstheme' ),
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
                'icons',
                [
                        'label'         => esc_html__( 'List Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $repeater->add_control(
            'list_text', [
                'label'         => esc_html__( 'Item Text', 'nsstheme' ),
                'type'		=> Controls_Manager::TEXTAREA,
                'label_block'	=> true,
                'placeholder'	=> esc_html__( 'Add Text', 'nsstheme' ),
                'default'	=> '',
            ]
        );
        $this->add_control(
            'list',
            [
                    'label'         => esc_html__( 'Listing Item', 'nsstheme' ),
                    'type'          => Controls_Manager::REPEATER,
                    'fields'        => $repeater->get_controls(),
                    'default'       => [
                            [
                                    'list_text'       => esc_html__( '', 'nsstheme' ),
                                    'icons'           => esc_html__( '', 'nsstheme' ),

                            ],
                    ],
                    'title_field' => '{{{ list_text }}}',
            ]
        );
        $this->add_responsive_control(
            'text_align', [
                'label'			=> esc_html__( 'Alignment', 'nsstheme' ),
                'type'			=> Controls_Manager::CHOOSE,
                'options'		=> [

                    'left'		=> [
                        'title'         => esc_html__( 'Left', 'nsstheme' ),
                        'icon'          => 'fa fa-align-left',
                    ],
                    'center'            => [
                        'title'         => esc_html__( 'Center', 'nsstheme' ),
                        'icon'          => 'fa fa-align-center',
                    ],
                    'right'		=> [
                        'title'         => esc_html__( 'Right', 'nsstheme' ),
                        'icon'          => 'fa fa-align-right',
                    ],
                ],
                'default'		        => 'left',
                'prefix_class'          => 'list_align elementor%s-align-',
            ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2', [
                'label'	 => esc_html__( 'Listing Icon', 'nsstheme' ),
                'tab'	 => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .listing li i',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'list_icon_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .listing li i',
                ]
        );
        $this->add_control(
                'list_icon_paddings',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .listing li i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'list_icon_margins',
                [
                        'label'         => esc_html__( 'Margins', 'nsstheme' ),
                        'type'          => Controls_Manager::DIMENSIONS,
                        'size_units'    => [ 'px', '%', 'em' ],
                        'selectors'     => [
                                '{{WRAPPER}} .listing li i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_3', [
                'label'  => esc_html__( 'Listing Content', 'nsstheme' ),
                'tab'    => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'list_typography',
                        'label'     => esc_html__( 'Listing Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .listing li',
                ]
        );
        $this->add_control(
                'list_color',
                [
                        'label'     => esc_html__( 'Listing Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .listing li' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'paddings',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .listing li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'margins',
                [
                        'label'         => esc_html__( 'Margins', 'nsstheme' ),
                        'type'          => Controls_Manager::DIMENSIONS,
                        'size_units'    => [ 'px', '%', 'em' ],
                        'selectors'     => [
                                '{{WRAPPER}} .listing li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
    }

    protected function render() {
        $settings       = $this->get_settings();
        $list           = (isset($settings['list']) && !empty($settings['list'])) ? $settings['list'] : array();
        
        if(count($list) > 0): ?>
            <ul class="listing">
                <?php 
                $i = 1; 
                foreach ($list as $item):
                    $icons      = (isset($item['icons'])) ? $item['icons'] : '';
                    $list_text  = (isset($item['list_text'])) ? $item['list_text'] : '';
                ?>
                <li>
                    <?php if($icons != ''): ?>
                        <i class="<?php echo esc_attr($icons); ?>"></i>
                    <?php endif; ?>
                    <?php echo habu_kses($list_text); ?>
                </li>
                <?php 
                $i++;
                endforeach;
                ?>
            </ul>
        <?php endif;
    }

    protected function _content_template() {

    }
}
