<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Mailchimp_Form_Widget extends Widget_Base {

    public function get_name() {
        return 'nss-mailchimp-form';
    }

    public function get_title() {
        return esc_html__( 'Mail Chimp From', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-mailchimp';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        global $wpdb;
        $table = $wpdb->prefix.'posts';
        $result = $wpdb->get_results( 'SELECT * FROM '.$table.' WHERE post_type="mc4wp-form" AND post_status="publish"', OBJECT );
        $shortcodes = array('0' => esc_html__('None', 'nsstheme'));
        if(is_array($result) && count($result) > 0){
            foreach($result as $r){
                $shortcodes[$r->ID] = $r->post_title;
            }
        }
        $this->start_controls_section(
            'section_tab_1', [
                'label'     => esc_html__( 'Mail Form', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'mail_form',
                [
                        'label'     => esc_html__( 'Select Form', 'nsstheme' ),
                        'type'      => Controls_Manager::SELECT,
                        'default'   => '',
                        'options'   => $shortcodes,
                ]
        );
        $this->add_responsive_control(
            'text_align', [
                'label'         => esc_html__( 'Alignment', 'nsstheme' ),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [

                    'left'      => [
                        'title'         => esc_html__( 'Left', 'nsstheme' ),
                        'icon'          => 'fa fa-align-left',
                    ],
                    'center'            => [
                        'title'         => esc_html__( 'Center', 'nsstheme' ),
                        'icon'          => 'fa fa-align-center',
                    ],
                    'right'     => [
                        'title'         => esc_html__( 'Right', 'nsstheme' ),
                        'icon'          => 'fa fa-align-right',
                    ],
                ],
                'default'               => 'right',
                'prefix_class'          => 'list_align elementor%s-align-',
            ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2', [
                'label'	 => esc_html__( 'Mail From Style', 'nsstheme' ),
                'tab'	 => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
                'input_color',
                [
                        'label'     => esc_html__( 'Input Field Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]' => 'color: {{VALUE}}',
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]::-moz-placeholder' => 'color: {{VALUE}} !important',
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]::-webkit-input-placeholder' => 'color: {{VALUE}} !important',
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]::-ms-input-placeholder' => 'color: {{VALUE}} !important',
                        ],
                ]
        );
        $this->add_control(
                'input_width',
                [
                        'label' => esc_html__( 'Input Field Width', 'nsstheme' ),
                        'type'  => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%' ],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 1000,
                                        'step' => 1,
                                ],
                                '%' => [
                                        'min' => 0,
                                        'max' => 100,
                                ],
                        ],
                        'default' => [],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]' => 'width: {{SIZE}}{{UNIT}};',
                        ],
                ]
            );
        $this->add_control(
                'input_height',
                [
                        'label' => esc_html__( 'Input Field Height', 'nsstheme' ),
                        'type'  => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%' ],
                        'range' => [
                                'px' => [
                                        'min' => 0,
                                        'max' => 200,
                                        'step' => 1,
                                ],
                                '%' => [
                                        'min' => 0,
                                        'max' => 100,
                                ],
                        ],
                        'default' => [],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]' => 'height: {{SIZE}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'input_typography',
                            'label'     => esc_html__( 'Input From Typography', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .mail_chimp_form input[type="email"]',
                    ]
            );
            $this->add_control(
                'input_paddings',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="email"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_4',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Label Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg_color',
                        [
                                'label' => esc_html__( 'Btn BG Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label' => esc_html__( 'Label Hover Color', 'nsstheme' ),
                                'type'  => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .mail_chimp_form input[type="submit"]:hover'  => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg_hover_color',
                        [
                                'label' => esc_html__( 'Btn Hover BG Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .mail_chimp_form input[type="submit"]:hover' => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_control(
			'btn_1_width',
			[
				'label' => esc_html__( 'Width', 'nsstheme' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [],
				'selectors' => [
					'{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
            $this->add_control(
			'btn_1_height',
			[
				'label' => esc_html__( 'Height', 'nsstheme' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [],
				'selectors' => [
					'{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .mail_chimp_form input[type="submit"]',
                    ]
            );
            $this->add_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .mail_chimp_form input[type="submit"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
        
        
    }
    
    protected function render() {
        $settings       = $this->get_settings();
        $mail_form      = (isset($settings['mail_form']) && $settings['mail_form'] != '') ? $settings['mail_form'] : '';
        
        if($mail_form > 0){
            echo '<div class="mail_chimp_form">';
                if($mail_form > 0):
                    echo do_shortcode('[mc4wp_form id="'.$mail_form.'"]');
                endif;
            echo '</div>';
        }else{
            ?>
            <div class="alert alert-warning" role="alert">
                <?php echo esc_html__('Please Select Mail Chimp From.', 'nsstheme'); ?>
            </div>
            <?php
        }
        
    }

    protected function _content_template() {

    }    
}