<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Portfolio extends Widget_Base{
    
    public function get_name() {
        return 'nss-portfolio';
    }
    
    public function get_title() {
        return esc_html__( 'Portfolio', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-post-list';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Portfolio', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'folio_is_filter',
                [
                        'label'             => esc_html__( 'Is Filter?', 'nsstheme' ),
                        'type'              => Controls_Manager::SWITCHER,
                        'label_on'          => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'         => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'      => 'yes',
                        'default'           => 'no',
                ]
        );
        $this->add_control(
                'folio_is_gaping',
                [
                        'label'             => esc_html__( 'Is Gapping?', 'nsstheme' ),
                        'type'              => Controls_Manager::SWITCHER,
                        'label_on'          => esc_html__( 'Show', 'nsstheme' ),
                        'label_off'         => esc_html__( 'Hide', 'nsstheme' ),
                        'return_value'      => 'yes',
                        'default'           => 'yes',
                ]
        );
        $this->add_control(
                'portfolio_item',
                [
                        'label'     => esc_html__( 'Number Of Item', 'nsstheme' ),
                        'type'      => Controls_Manager::NUMBER,
                        'min'       => 3,
                        'max'       => 100,
                        'step'      => 1,
                        'default'   => 6,
                ]
        );
        $this->add_control(
                'order_by',
                [
                        'label' => esc_html__( 'Order By', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'date',
                        'options' => [
                                'date'       => esc_html__( 'Date', 'nsstheme' ),
                                'title'      => esc_html__( 'Title', 'nsstheme' ),
                                'rand'       => esc_html__( 'Random', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'order',
                [
                        'label' => esc_html__( 'Order', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'desc',
                        'options' => [
                                'asc'       => esc_html__( 'Ascending', 'nsstheme' ),
                                'desc'      => esc_html__( 'Descending', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'read_more_label',
                [
                        'label'         => esc_html__( 'Read More Label', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '',
                        'label_block'   => TRUE,
                        'placeholder'   => esc_html__('insert read more label.', 'nsstheme'),
                ]
        );
        $this->add_control(
                'icons',
                [
                        'label'     => esc_html__( 'Read More Icons', 'nsstheme' ),
                        'type'      => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2',
            [
                'label'             => esc_html__('Folio Overlay Color', 'nsstheme'),
                'tab'               => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'overlay_background',
                'label'     => esc_html__( 'Background', 'nsstheme' ),
                'types'     => [ 'classic', 'gradient', 'video' ],
                'selector'  => '{{WRAPPER}} .folio-item-1:after',
            ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Read More BTN Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->start_controls_tabs( 'style_tabs_13' );
            $this->start_controls_tab(
                    'f_2_style_rm_normal',
                    [
                            'label' => esc_html__( 'Normal', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'f_text_normal_color',
                    [
                            'label' => esc_html__( 'Text Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .folio-item-1 a' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'f_2_rm_normal_color',
                    [
                            'label' => esc_html__( 'Icon Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .folio-item-1 a i' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->end_controls_tab();
            $this->start_controls_tab(
                    'f_2_style_rm_hover',
                    [
                            'label' => esc_html__( 'Hover', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'f_text_hover_color',
                    [
                            'label' => esc_html__( 'Text Hover Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .folio-item-1 a:hover' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'f_2_rm_hover_color',
                    [
                            'label' => esc_html__( 'Icon Hover Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .folio-item-1 a:hover i' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'f_text_typography',
                        'label'     => esc_html__( 'Text Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .folio-item-1 a',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'f_2_rm_icon_typography',
                        'label'     => esc_html__( 'Icon Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .folio-item-1 a i',
                ]
        );
        $this->add_control(
                'f_text_padding',
                [
                        'label'      => esc_html__( 'Text Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .folio-item-1 a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'f_icon_padding',
                [
                        'label'      => esc_html__( 'Icon Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .folio-item-1 a i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        
    }
    
    protected function render() {
        $settings           = $this->get_settings();

        $folio_is_filter    = (isset($settings['folio_is_filter'])) ? $settings['folio_is_filter'] : 'yes';
        $folio_is_gaping    = (isset($settings['folio_is_gaping'])) ? $settings['folio_is_gaping'] : 'yes';
        $portfolio_item     = (isset($settings['portfolio_item']) && $settings['portfolio_item'] > 0) ? $settings['portfolio_item'] : 6;
        $order_by           = (isset($settings['order_by']) && $settings['order_by'] != '') ? $settings['order_by'] : 'date';
        $order              = (isset($settings['order']) && $settings['order'] != '') ? $settings['order'] : 'desc';
        
        $read_more_label    = (isset($settings['read_more_label']) && $settings['read_more_label'] != '') ? $settings['read_more_label'] : '';
        $icons              = $settings['icons'];
        
        
        include  dirname(__FILE__).'/style/folio/style1.php';
        
    }
    
    protected function _content_template() {
        
    }
}