<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Post extends Widget_Base{
    
    public function get_name() {
        return 'nss-post';
    }
    
    public function get_title() {
        return esc_html__( 'Post', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-post-list';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_tab', [
                'label' => esc_html__( 'Post', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'post_style',
                [
                        'label'     => esc_html__( 'Post Style', 'nsstheme' ),
                        'label_block' => true,
                        'type'      => Controls_Manager::SELECT,
                        'default'   => 1,
                        'options'   => [
                                1                   => esc_html__( 'Grid Style', 'nsstheme' ),
                                2                   => esc_html__( 'Slider Style', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'post_item',
                [
                        'label'         => esc_html__( 'Number Of Item', 'nsstheme' ),
                        'type'          => Controls_Manager::NUMBER,
                        'min'           => 1,
                        'max'           => 200,
                        'step'          => 1,
                        'default'       => 3,
                        'description'   => esc_html__( 'How many post item you want to show?.', 'nsstheme' ),
                ]
        );
        $this->add_control(
                'post_order_by',
                [
                        'label' => esc_html__( 'Order By', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'date',
                        'options' => [
                                'date'                  => esc_html__( 'Date', 'nsstheme' ),
                                'title'                 => esc_html__( 'Title', 'nsstheme' ),
                                'rand'                  => esc_html__( 'Random', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'post_order',
                [
                        'label' => esc_html__( 'Order', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'desc',
                        'options' => [
                                'asc'        => esc_html__( 'Ascending', 'nsstheme' ),
                                'desc'       => esc_html__( 'Descending', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'read_more_label',
                [
                        'label'         => esc_html__( 'Read More Label', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '',
                        'label_block'   => TRUE,
                        'placeholder'   => esc_html__('insert read more label.', 'nsstheme'),
                ]
        );
        $this->add_control(
                'icons',
                [
                        'label'     => esc_html__( 'Read More Icons', 'nsstheme' ),
                        'type'      => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
                'post_desc_lenght',
                [
                        'label'     => esc_html__( 'Content Lenght', 'nsstheme' ),
                        'type'      => Controls_Manager::NUMBER,
                        'min'       => 0,
                        'max'       => 1000,
                        'step'      => 5,
                        'default'   => 97,
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_03', [
                    'label'             => esc_html__('Post Area', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                'cl_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .blog-post' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'cl_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .blog-post',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'cl_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .blog-post',
                ]
        );
        $this->add_control(
            'box_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .blog-post' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_responsive_control(
                'post_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .blog-post' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_04', [
                    'label'             => esc_html__('Category Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_responsive_control(
                'cate_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} a.cats' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_responsive_control(
                'cate_bg_color',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} a.cats' => 'background: {{VALUE}}',
                        ],
                ]
        );
        $this->add_responsive_control(
                'cate_hover_color',
                [
                        'label' => esc_html__( 'Hover Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} a.cats:hover' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_responsive_control(
                'cate_hover_bg_color',
                [
                        'label' => esc_html__( 'Hover BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} a.cats:hover' => 'background: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'cate_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}}  a.cats',
                ]
        );
        $this->add_responsive_control(
                'cate_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} a.cats' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'cate_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} a.cats' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_05', [
                    'label'             => esc_html__('Title Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_responsive_control(
                'title_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .post_content h3' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_responsive_control(
                'title_hover_color',
                [
                        'label' => esc_html__( 'Hover Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .post_content h3 a:hover' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'title_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}}  .post_content h3',
                ]
        );
        $this->add_responsive_control(
                'post_title_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .post_content h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_07', [
                    'label'             => esc_html__('Description Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_responsive_control(
                'desc_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .post_content p' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'post_desc_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .post_content p',
                ]
        );
        $this->add_responsive_control(
                'desc_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .post_content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'cl_desc_border',
                        'label' => esc_html__( 'Border Bottom', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .bp_meta',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_08', [
                    'label'             => esc_html__('Date Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_responsive_control(
                'date_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .bp_meta span' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'date_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .bp_meta span',
                ]
        );
        $this->add_responsive_control(
                'date_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .bp_meta span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_10',[
                    'label'         => esc_html__('Read More BTN Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->start_controls_tabs( 'style_tabs_13' );
            $this->start_controls_tab(
                    'f_2_style_rm_normal',
                    [
                            'label' => esc_html__( 'Normal', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'f_text_normal_color',
                    [
                            'label' => esc_html__( 'Text Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .bp_meta a' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'f_2_rm_normal_color',
                    [
                            'label' => esc_html__( 'Icon Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .bp_meta a i' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->end_controls_tab();
            $this->start_controls_tab(
                    'f_2_style_rm_hover',
                    [
                            'label' => esc_html__( 'Hover', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'f_text_hover_color',
                    [
                            'label' => esc_html__( 'Text Hover Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .bp_meta a:hover' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'f_2_rm_hover_color',
                    [
                            'label' => esc_html__( 'Icon Hover Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .bp_meta a:hover i' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'f_text_typography',
                        'label'     => esc_html__( 'Text Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .bp_meta a',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'f_2_rm_icon_typography',
                        'label'     => esc_html__( 'Icon Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .bp_meta a i',
                ]
        );
        $this->add_control(
                'f_text_padding',
                [
                        'label'      => esc_html__( 'Text Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .bp_meta a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'f_icon_padding',
                [
                        'label'      => esc_html__( 'Icon Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .bp_meta a i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings       = $this->get_settings();
        
        $post_style     = (isset($settings['post_style']) && $settings['post_style'] > 0) ? $settings['post_style'] : 1;
        $post_item      = (isset($settings['post_item']) && $settings['post_item'] > 0) ? $settings['post_item'] : 3;
        $post_order_by  = (isset($settings['post_order_by']) && $settings['post_order_by'] != '') ? $settings['post_order_by'] : 'date';
        $post_order     = (isset($settings['post_order']) && $settings['post_order'] != '') ? $settings['post_order'] : 'desc';

        $post_desc_lenght    = (isset($settings['post_desc_lenght']) && $settings['post_desc_lenght'] > 0) ? $settings['post_desc_lenght'] : 97;

        $read_more_label    = (isset($settings['read_more_label']) && $settings['read_more_label'] != '') ? $settings['read_more_label'] : '';
        $icons              = $settings['icons'];

        
        include  dirname(__FILE__).'/style/post/style'.$post_style.'.php';
    }
    
    protected function _content_template() {
        
    }
}