<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Pricing_Widgets extends Widget_Base {

    public function get_name() {
        return 'nss-pricing';
    }

    public function get_title() {
        return esc_html__( 'Pricing', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label'     => esc_html__( 'Pricing Content', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'p_icons',
                [
                        'label'         => esc_html__( 'Price Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
            'title', [
                'label'       => esc_html__( 'Pricing Title', 'nsstheme' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__( 'title here', 'nsstheme' ),
                'default'     => esc_html__( 'Consultation', 'nsstheme' ),
            ]
        );
        $this->add_control(
            'price', [
                'label'       => esc_html__( 'Pricing Here.', 'nsstheme' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$ 40 / h', 'nsstheme' ),
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
                'icons',
                [
                        'label'         => esc_html__( 'List Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $repeater->add_control(
            'list_text', [
                'label'         => esc_html__( 'Item Text', 'nsstheme' ),
                'type'		=> Controls_Manager::TEXTAREA,
                'label_block'	=> true,
                'placeholder'	=> esc_html__( 'Add Text', 'nsstheme' ),
                'default'	=> '',
            ]
        );
        $this->add_control(
            'list',
            [
                    'label'         => esc_html__( 'Listing Item', 'nsstheme' ),
                    'type'          => Controls_Manager::REPEATER,
                    'fields'        => $repeater->get_controls(),
                    'default'       => [
                            [
                                    'list_text'       => esc_html__( '', 'nsstheme' ),
                                    'icons'           => esc_html__( '', 'nsstheme' ),

                            ],
                    ],
                    'title_field' => '{{{ list_text }}}',
            ]
        );
        $this->add_control(
               'btn_label', [
                    'label'             => esc_html__('Button Label', 'nsstheme'),
                    'type'              => Controls_Manager::TEXT,
                    'label_block'       => true,
                    'default'           => '',
                    'placeholder'       => esc_html__('Inser Button Label', 'nsstheme'),
                ]
        );
        $this->add_control(
                'btn_url', [
                    'label'             => esc_html__( 'URL', 'nsstheme' ),
                    'type'              => Controls_Manager::URL,
                    'input_type'        => 'url',
                    'placeholder'       => esc_html__( 'https://your-link.com', 'nsstheme' ),
                    'show_external'     => true,
                    'default'           => [
                            'url'            => '',
                            'is_external'    => true,
                            'nofollow'       => true,
                    ],
                ]
        );
        $this->add_responsive_control(
                'Alignment', [
                        'label'                     => esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'              => [
                                        'title'     => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-left',
                                ],
                                'center'            => [
                                        'title'     => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-center',
                                ],
                                'right'             => [
                                        'title'     => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'center',
                        'prefix_class'              => 'price_align elementor%s-align-',
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_2',[
                    'label'     => esc_html__('Pricing Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'p_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .price-item' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'p_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .price-item',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'p_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .price-item',
                ]
        );
        $this->add_control(
            'p_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .price-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_control(
                'p_area_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .price-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'p_area_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .price-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_i_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .price-item > i',
                ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .price-item > i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .price-item > i',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_4',[
                    'label'         => esc_html__('Title Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'icon_box_title_color',[
                        'label'     => esc_html__( 'Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .price-item h4' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_title_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .price-item h4',
                ]
        );
        $this->add_control(
                'icon_box_title_pading',
                [
                        'label'      => esc_html__( 'Padding', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .price-item h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'icon_box_title_margin',
                [
                        'label'      => esc_html__( 'Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .price-item h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'title_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .price-item h4',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_6',[
                    'label'         => esc_html__('Price Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'price_color',[
                        'label'     => esc_html__( 'Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .price' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_control(
                'price_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .price' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
            'price_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'price_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .price',
                ]
        );
        $this->add_control(
                'price_padding',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'price_margin',
                [
                        'label'      => esc_html__( 'Margins', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_7', [
                'label'	 => esc_html__( 'Listing Icon', 'nsstheme' ),
                'tab'	 => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
                'list_icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'list_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .price-item ul li i',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'list_icon_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .price-item ul li i',
                ]
        );
        $this->add_control(
                'list_icon_margins',
                [
                        'label'         => esc_html__( 'Margins', 'nsstheme' ),
                        'type'          => Controls_Manager::DIMENSIONS,
                        'size_units'    => [ 'px', '%', 'em' ],
                        'selectors'     => [
                                '{{WRAPPER}} .price-item ul li i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_8', [
                'label'  => esc_html__( 'Listing Content', 'nsstheme' ),
                'tab'    => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'list_typography',
                        'label'     => esc_html__( 'Listing Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .price-item ul li',
                ]
        );
        $this->add_control(
                'list_color',
                [
                        'label'     => esc_html__( 'Listing Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .price-item ul li' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'paddings',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .price-item ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'margins',
                [
                        'label'         => esc_html__( 'Margins', 'nsstheme' ),
                        'type'          => Controls_Manager::DIMENSIONS,
                        'size_units'    => [ 'px', '%', 'em' ],
                        'selectors'     => [
                                '{{WRAPPER}} .price-item ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_10',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .price-item .habu-btn'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                                'name'      => 'btn_1_bg',
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'types'     => [ 'classic', 'gradient', 'video' ],
                                'selector'  => '{{WRAPPER}} .price-item .habu-btn',
                        ]
                );
                $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                                'name' => 'btn_1_border',
                                'label' => esc_html__( 'Border', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .price-item .habu-btn',
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label'     => esc_html__( 'Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .price-item .habu-btn:hover'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                                'name'      => 'btn_1_hover_bg',
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'types'     => [ 'classic', 'gradient', 'video' ],
                                'selector'  => '{{WRAPPER}} .price-item .habu-btn:after',
                        ]
                );
                $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                                'name' => 'btn_1_hover_border',
                                'label' => esc_html__( 'Border', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .price-item .habu-btn',
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_responsive_control(
                'btn_1_width',
                [
                    'label' => esc_html__( 'Width', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .price-item .habu-btn' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_height',
                [
                    'label' => esc_html__( 'Height', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 200,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                            '{{WRAPPER}} .price-item .habu-btn' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .price-item .habu-btn',
                    ]
            );
            $this->add_responsive_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                            '{{WRAPPER}} .price-item .habu-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            '{{WRAPPER}} .price-item .habu-btn:after'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .price-item .habu-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_responsive_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .price-item .habu-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
        
    }

    protected function render() {
        $settings       = $this->get_settings();
        $p_icons        = $settings['p_icons'];
        $title          = $settings['title'];
        $price          = $settings['price'];
        $list           = (isset($settings['list']) && !empty($settings['list'])) ? $settings['list'] : array();
        $btn_label      = $settings['btn_label'] ? $settings['btn_label'] : esc_html__('Buy Now', 'nsstheme');
        
        $btn_url        = (isset($settings['btn_url']['url']) && $settings['btn_url']['url'] != '') ? $settings['btn_url']['url'] : '#';
        
        ?>

        <div class="price-item">
            <?php if($p_icons != ''): ?>
                <i class="<?php echo esc_attr($p_icons); ?>"></i>
            <?php endif; ?>
            <?php if($title != ''): ?>
                <h4><?php echo esc_html($title); ?></h4>
            <?php endif; ?>
            <?php if($price != ''): ?>
                <div class="price"><?php echo esc_html($price); ?></div>
            <?php endif; ?>
            <?php if(count($list) > 0): ?>
                <ul>
                    <?php 
                    $i = 1; 
                    foreach ($list as $item):
                        $icons      = (isset($item['icons'])) ? $item['icons'] : '';
                        $list_text  = (isset($item['list_text'])) ? $item['list_text'] : '';
                    ?>
                    <li>
                        <?php if($icons != ''): ?>
                            <i class="<?php echo esc_attr($icons); ?>"></i>
                        <?php endif; ?>
                        <?php echo habu_kses($list_text); ?>
                    </li>
                    <?php 
                    $i++;
                    endforeach;
                    ?>
                </ul>
            <?php endif; ?>
            <?php if($btn_label != ''): ?>
                <a href="<?php echo esc_url($btn_url); ?>" class="habu-btn"><span><?php echo esc_html($btn_label); ?></span></a>
            <?php endif; ?>
        </div><?php
    }

    protected function _content_template() {

    }
}
