<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Section_Title_Widget extends Widget_Base {
    public function get_name() {
        return 'nss-section-title';
    }
    public function get_title() {
        return esc_html__('Section Title', 'nsstheme');
    }
    public function get_icon() {
        return 'eicon-t-letter';
    }
    public function get_categories() {
        return ['habu-elements'];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab', [
                'label'         => esc_html__( 'Section Title', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'section_text', [
                    'label'             => esc_html__('Section Tilte', 'nsstheme'),
                    'type'              => Controls_Manager::TEXTAREA,
                    'label_block'       => TRUE,
                    'default'           => esc_html__('Add Title', 'nsstheme')
                ]
        );
        $this->add_control(
                'section_desc', [
                    'label'             => esc_html__('Section Description', 'nsstheme'),
                    'type'              => Controls_Manager::TEXTAREA,
                    'label_block'       => TRUE,
                    'default'           => esc_html__('Add Desc', 'nsstheme')
                ]
        );
        $this->add_responsive_control(
                'section_alignment', [
                        'label'                     => esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'              => [
                                        'title'     => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-left',
                                ],
                                'center'            => [
                                        'title'     => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-center',
                                ],
                                'right'             => [
                                        'title'     => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'      => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'left',
                        'prefix_class'              => 'habu_sec_align elementor%s-align-',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_2', [
                'label'         => esc_html__( 'Title', 'nsstheme' ),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->add_responsive_control(
                'sec_1_color', [
                        'label'		 => esc_html__( 'Color', 'nsstheme' ),
                        'type'		 => Controls_Manager::COLOR,
                        'selectors'	 => [
                            '{{WRAPPER}} .sec_titles' => 'color: {{VALUE}};'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'sec_1_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .sec_titles',
                ]
        );
        $this->add_responsive_control(
                'sec_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .sec_titles' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'sec_1_margin',
                [
                        'label' => esc_html__( 'Marign', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .sec_titles' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_tab_3', [
                'label'         => esc_html__( 'Description', 'nsstheme' ),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->add_responsive_control(
                'sec_2_color', [
                        'label'      => esc_html__( 'Color', 'nsstheme' ),
                        'type'       => Controls_Manager::COLOR,
                        'selectors'  => [
                            '{{WRAPPER}} .sec_desc' => 'color: {{VALUE}};'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'sec_2_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .sec_desc',
                ]
        );
        $this->add_responsive_control(
                'sec_2_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .sec_desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'sec_2_margin',
                [
                        'label' => esc_html__( 'Marign', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .sec_desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings           = $this->get_settings();
        $section_text       = $settings['section_text'];
        $section_desc       = $settings['section_desc'];
        
        ?>
        <?php if($section_text != ''): ?>
           <h2 class="sec_titles"><?php echo habu_kses($section_text); ?></h2> 
        <?php endif; ?>
        <?php if($section_desc != ''): ?>
           <p class="sec_desc"><?php echo habu_kses($section_desc); ?></p> 
        <?php endif; ?>
        <?php
    }
    
    protected function _content_template() {
        
    }
}