<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Services extends Widget_Base{
    
    public function get_name() {
        return 'nss-service';
    }
    
    public function get_title() {
        return esc_html__( 'Service Box', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab', [
                'label' => esc_html__( 'Services', 'nsstheme' ),
            ]
        );
            $this->add_control(
                    'box_style',
                    [
                            'label'     => esc_html__( 'Service Style', 'nsstheme' ),
                            'label_block' => true,
                            'type'      => Controls_Manager::SELECT,
                            'default'   => 1,
                            'options'   => [
                                    1                   => esc_html__( 'Icon Style', 'nsstheme' ),
                                    2                   => esc_html__( ' Image Style', 'nsstheme' ),
                            ],
                    ]
            );
            $this->add_control(
                    'icons',
                    [
                            'label'     => esc_html__( 'Icons', 'nsstheme' ),
                            'type'      => Controls_Manager::ICON,
                            'label_block'   => TRUE,
                    ]
            );
            $this->add_control(
                    'icon_align',
                    [
                            'label'     => esc_html__( 'Icon Alignment', 'nsstheme' ),
                            'type'      => Controls_Manager::SELECT,
                            'default'   => 1,
                            'options'   => [
                                    1       => esc_html__( 'Left', 'nsstheme' ),
                                    2       => esc_html__( 'Right', 'nsstheme' ),
                                    3       => esc_html__( 'Top', 'nsstheme' ),
                            ],
                    ]
            );
            $this->add_control(
                    'box_title',
                    [
                            'label'         => esc_html__( 'Title', 'nsstheme' ),
                            'type'          => Controls_Manager::TEXTAREA,
                            'default'       => '',
                            'label_block'   => TRUE,
                            'placeholder'   => esc_html__('Box Title', 'nsstheme'),
                    ]
            );
            $this->add_control(
                    'is_link',
                    [
                            'label'             => esc_html__( 'Is Link?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to link this title?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'no',
                    ]
            );
            $this->add_control(
                    'title_url', [
                        'label'             => esc_html__( 'URL', 'nsstheme' ),
                        'type'              => Controls_Manager::URL,
                        'input_type'        => 'url',
                        'condition'         => ['is_link' => 'yes'],
                        'placeholder'       => esc_html__( 'https://your-link.com', 'nsstheme' ),
                        'show_external'     => true,
                        'default'           => [
                                'url'            => '',
                                'is_external'    => true,
                                'nofollow'       => true,
                        ],
                    ]
            );
            $this->add_control(
                    'box_desc',
                    [
                            'label'         => esc_html__( 'Desccription', 'nsstheme' ),
                            'type'          => Controls_Manager::TEXTAREA,
                            'default'       => '',
                            'label_block'   => TRUE,
                            'placeholder'   => esc_html__('Desc', 'nsstheme'),
                    ]
            );
            $this->add_responsive_control(
                    'box_alignment', [
                            'label'                     =>esc_html__( 'Box Alignment', 'nsstheme' ),
                            'type'                      => Controls_Manager::CHOOSE,
                            'options'                   => [
                                    'left'		 => [
                                            'title'	 =>esc_html__( 'Left', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-left',
                                    ],
                                    'center'	 => [
                                            'title'	 =>esc_html__( 'Center', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-center',
                                    ],
                                    'right'		 => [
                                            'title'	 =>esc_html__( 'Right', 'nsstheme' ),
                                            'icon'	 => 'fa fa-align-right',
                                    ]
                            ],
                            'default'                   => 'left',
                            'prefix_class'              => 'service_holder elementor%s-align-',
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_1', [
                    'label'         => esc_html__('Box Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
           $this->start_controls_tabs( 'item_styling_tab' );
                $this->start_controls_tab(
                        'item_styling_tab_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'cl_item_bg',
                        [
                                'label' => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'  => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .service-item-1' => 'background: {{VALUE}}'
                                ],
                        ]
                );
                $this->add_group_control(
                        Group_Control_Box_Shadow::get_type(),
                        [
                                'name' => 'cl_item_shadow',
                                'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .service-item-1',
                        ]
                );
                $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                                'name' => 'cl_item_border',
                                'label' => esc_html__( 'Border', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .service-item-1',
                        ]
                );
                $this->add_control(
                    'box_border_radius',
                    [
                            'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                ]
                    ]
                );
                $this->end_controls_tab();

                $this->start_controls_tab(
                        'item_styling_tab_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'cl_item_bg_hover',
                        [
                                'label' => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'  => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .service-item-1:hover' => 'background: {{VALUE}}'
                                ],
                        ]
                );
                $this->add_group_control(
                        Group_Control_Box_Shadow::get_type(),
                        [
                                'name' => 'cl_item_shadow_hover',
                                'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .service-item-1:hover',
                        ]
                );
                $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                                'name' => 'cl_item_border_hover',
                                'label' => esc_html__( 'Border', 'nsstheme' ),
                                'selector' => '{{WRAPPER}} .service-item-1:hover',
                        ]
                );
                $this->add_control(
                    'box_hover_border_radius',
                    [
                            'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                ]
                    ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_responsive_control(
                    'icon_box_padding',
                    [
                            'label' => esc_html__( 'Paddings', 'nsstheme' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_responsive_control(
                    'icon_box_margin',
                    [
                            'label' => esc_html__( 'Margins', 'nsstheme' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_2',[
                    'label'         => esc_html__('Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_i_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .service-item-1 i',
                ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .service-item-1 i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .service-item-1 i',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Title Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
            $this->add_control(
                    'icon_box_title_color',[
                            'label'     => esc_html__( 'Color', 'nsstheme' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1 h3' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    'icon_box_title_hover_color',[
                            'label'     => esc_html__( 'Hover Color', 'nsstheme' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1 h3 a:hover' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'icon_box_title_typo',
                            'label'     => esc_html__( 'Typography', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .service-item-1 h3',
                    ]
            );
            $this->add_control(
                    'icon_box_title_pading',
                    [
                            'label'      => esc_html__( 'Padding', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .service-item-1 h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'icon_box_title_margin',
                    [
                            'label'      => esc_html__( 'Margin', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .service-item-1 h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_4',[
                    'label'         => esc_html__('Description Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
            $this->add_control(
                    'icon_box_desc_color',[
                            'label'     => esc_html__( 'Color', 'nsstheme' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .service-item-1 p' => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name'      => 'icon_box_desc_typo',
                            'label'     => esc_html__( 'Typography', 'nsstheme' ),
                            'selector'  => '{{WRAPPER}} .service-item-1 p',
                    ]
            );
            $this->add_control(
                    'icon_box_desc_pading',
                    [
                            'label'      => esc_html__( 'Padding', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .service-item-1 p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
            $this->add_control(
                    'icon_box_desc_margin',
                    [
                            'label'      => esc_html__( 'Margin', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .service-item-1 p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
        
    }
    
    protected function render() {
        $settings   = $this->get_settings();

        $box_style   = (isset($settings['box_style']) && $settings['box_style'] > 0) ? $settings['box_style'] : 1;

        $icons       = $settings['icons'];
        $icon_align  = $settings['icon_align'];
        $box_title   = $settings['box_title'];
        $is_link     = $settings['is_link'];
        $box_desc    = $settings['box_desc'];
        $url         = $settings['title_url']['url'] ? $settings['title_url']['url'] : '#';
        $target      = $settings['title_url']['is_external'] ? ' target="_blank"' : '' ;
        $nofollow    = $settings['title_url']['nofollow'] ? ' rel="nofollow"' : '' ;
        
        $classes = '';
        if($icon_align == 2 && $icons != ''){
            $classes .= ' ib_icon_in_right';
        }elseif($icon_align == 3 && $icons != ''){
            $classes .= ' ib_icon_on_top';
        }
        
        include  dirname(__FILE__).'/style/service/style'.$box_style.'.php';
        
    }
    
    protected function _content_template() {

    }
    
    
}