<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Skills_Widgets extends Widget_Base{
    
    public function get_name() {
        return 'nss-skills';
    }
    
    public function get_title() {
        return esc_html__( 'Skills', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-skill-bar';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Skills', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'skill_title',
                [
                        'label'         => esc_html__( 'Skill Title', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '',
                        'label_block'   => true,
                        'placeholder'   => esc_html__('Skill Title', 'nsstheme')
                ]
        );
        $this->add_control(
                'percent',
                [
                        'label'         => esc_html__( 'Precent', 'nsstheme' ),
                        'type'          => Controls_Manager::NUMBER,
                        'default'       => esc_html__('85', 'nsstheme'),
                        'placeholder'   => esc_html__('Precent', 'nsstheme')
                ]
        );
        $this->add_control(
                'p_bg_color',
                [
                        'label'     => esc_html__( ' Line BG Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                ]
        );   
        $this->add_control(
                'p_fgroun_1_color',
                [
                        'label'     => esc_html__( ' Line For Ground Color 1', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                ]
        );   
        $this->add_control(
                'p_fgroun_2_color',
                [
                        'label'     => esc_html__( ' Line For Ground Color 2', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                ]
        );
        $this->add_control(
                'size',
                [
                        'label'         => esc_html__( 'Size Round', 'nsstheme' ),
                        'type'          => Controls_Manager::NUMBER,
                        'default'       => '180',
                        'placeholder'   => esc_html__('Round size heigh width size here.', 'nsstheme')
                ]
        );
        $this->add_control(
                'border',
                [
                        'label'         => esc_html__( 'Border Thickness Size', 'nsstheme' ),
                        'type'          => Controls_Manager::NUMBER,
                        'default'       => '12',
                        'placeholder'   => esc_html__('Round border size here.', 'nsstheme')
                ]
        );
        $this->add_responsive_control(
                'box_alignment', [
                        'label'                     =>esc_html__( 'Box Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'       => [
                                        'title'  =>esc_html__( 'Left', 'nsstheme' ),
                                        'icon'   => 'fa fa-align-left',
                                ],
                                'center'     => [
                                        'title'  =>esc_html__( 'Center', 'nsstheme' ),
                                        'icon'   => 'fa fa-align-center',
                                ],
                                'right'      => [
                                        'title'  =>esc_html__( 'Right', 'nsstheme' ),
                                        'icon'   => 'fa fa-align-right',
                                ]
                        ],
                        'default' => 'center',
                        'selectors' => [
                            '{{WRAPPER}} .habu_circle_skill'   => 'text-align: {{VALUE}};',
                         
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_2',[
                    'label'     => esc_html__('Skill Area Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                    'skill_margin',
                    [
                            'label'      => esc_html__( 'Margins', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .habu_circle_skill' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
        );
        $this->add_control(
                    'skill_padding',
                    [
                            'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                            'type'       => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors'  => [
                                    '{{WRAPPER}} .habu_circle_skill' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_4',[
                    'label'     => esc_html__('Skill Title Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                    'title_color',[
                            'label'     => esc_html__( 'Title Color', 'nsstheme' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .habu_circle_skill h5' => 'color: {{VALUE}}',
                            ],
                    ]
          );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'title_typography',
                        'label'     => esc_html__( 'Title Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .habu_circle_skill h5',
                ]
        );
        $this->add_control(
                    'title_margin',
                    [
                            'label' => esc_html__( 'Margins', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .habu_circle_skill h5' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                    ]
            );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_5',[
                    'label'     => esc_html__('Skill Percent Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                'percent_options',
                [
                        'label'     => esc_html__( 'Percent Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'percent_color',
                        'label'     => esc_html__( 'Percent Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .habu_circle_skill strong',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'percent_typography',
                        'label'     => esc_html__( 'Percent Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .habu_circle_skill strong',
                ]
        );
        $this->add_control(
                'percent_margin',
                [
                        'label'      => esc_html__( 'Margins', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .habu_circle_skill strong' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'percent_padding',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .habu_circle_skill strong' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        
        
    }
    
    protected function render() {
        $settings       = $this->get_settings_for_display();
        $skill_title    = (isset($settings['skill_title']) && $settings['skill_title'] != '') ? $settings['skill_title'] : '';
        $percent        = (isset($settings['percent']) && $settings['percent'] != '') ? $settings['percent'] : '85';
        $size         = (isset($settings['size']) && $settings['size'] != '') ? $settings['size'] : '180';
        $border         = (isset($settings['border']) && $settings['border'] != '') ? $settings['border'] : '12';
        
        $p_bg_color             = (isset($settings['p_bg_color']) && $settings['p_bg_color'] != '') ? $settings['p_bg_color'] : 'rgba(248, 248, 248, 1)';
        $p_fgroun_1_color       = (isset($settings['p_fgroun_1_color']) && $settings['p_fgroun_1_color'] != '') ? $settings['p_fgroun_1_color'] : '#01beff';
        $p_fgroun_2_color       = (isset($settings['p_fgroun_2_color']) && $settings['p_fgroun_2_color'] != '') ? $settings['p_fgroun_2_color'] : '#5461ff';
        
        ?>
            <div class="habu_circle_skill">
                <div class="habu_sk" data-border="<?php echo esc_attr($border); ?>" data-size="<?php echo esc_attr($size); ?>" data-bg="<?php echo esc_attr($p_bg_color); ?>" data-skills="0.<?php echo esc_html($percent); ?>" data-gradientstart="<?php echo esc_attr($p_fgroun_1_color); ?>" data-gradientend="<?php echo esc_attr($p_fgroun_2_color); ?>">
                    <strong></strong>
                </div>
                <?php if($skill_title != ''): ?>
                    <h5><?php echo esc_html($skill_title); ?></h5>
                <?php endif; ?>
            </div>
        <?php
    }
    
    protected function _content_template() {

    }
}