<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Team_Widgets extends Widget_Base{
    
    public function get_name() {
        return 'nss-team';
    }
    public function get_title() {
        return esc_html__( 'Team', 'nsstheme' );
    }
    public function get_icon() {
        return 'eicon-person';
    }
    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Single Member', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'image',
                [
                        'label'         => esc_html__( 'Team Meber Image', 'nsstheme' ),
                        'type'          => Controls_Manager::MEDIA,
                        'description'   => esc_html__('image size should be 170x170px.', 'nsstheme'),
                ]
        );
        $this->add_control(
            'name', [
                'label'       => esc_html__( 'Member Name', 'nsstheme' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__( 'Name here', 'nsstheme' ),
                'default'     => esc_html__( 'Jackson Nash', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'is_link',
                [
                        'label'             => esc_html__( 'Is Link?', 'nsstheme' ),
                        'type'              => Controls_Manager::SWITCHER,
                        'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                        'label_off'         => esc_html__( 'No', 'nsstheme' ),
                        'description'       => esc_html__('Do you want to link this title?', 'nsstheme'),
                        'return_value'      => 'yes',
                        'default'           => 'no',
                ]
        );
        $this->add_control(
            'team_link', [
                'label'       => esc_html__( 'Member Url', 'nsstheme' ),
                'type'        => Controls_Manager::URL,
                'label_block' => true,
                'condition'   => ['is_link' => 'yes'],
            ]
        );
        $this->add_control(
            'designation', [
                'label'       => esc_html__( 'Member Designation', 'nsstheme' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__( 'designation here', 'nsstheme' ),
                'default'     => esc_html__( 'Massagist', 'nsstheme' ),
            ]
        );

        $social = new \Elementor\Repeater();
        $social->add_control(
                'icons',
                [
                        'label'         => esc_html__( 'Social Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $social->add_control(
            'link', [
                'label'       => esc_html__( 'Url', 'nsstheme' ),
                'type'        => Controls_Manager::URL,
                'label_block' => true,
            ]
        );
        $social->add_control(
            'title', [
                'label'         => esc_html__( 'Name', 'nsstheme' ),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__( 'Social Name' , 'nsstheme' ),
                'label_block'   => true,
            ]
        );
        $this->add_control(
            'social_list',
            [
                'label'     => esc_html__( 'Social List', 'nsstheme' ),
                'type'      => Controls_Manager::REPEATER,
                'fields'    => $social->get_controls(),
                'default'   => [
                        [
                            'list_title' => esc_html__( 'Facebook', 'nsstheme' ),
                        ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->add_responsive_control(
                'team_align', [
                        'label'                     =>esc_html__( 'Alignment', 'nsstheme' ),
                        'type'                      => Controls_Manager::CHOOSE,
                        'options'                   => [
                                'left'		 => [
                                        'title'	 => esc_html__( 'Left', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-left',
                                ],
                                'center'	 => [
                                        'title'	 => esc_html__( 'Center', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-center',
                                ],
                                'right'		 => [
                                        'title'	 => esc_html__( 'Right', 'nsstheme' ),
                                        'icon'	 => 'fa fa-align-right',
                                ]
                        ],
                        'default'                   => 'center',
                        'prefix_class'              => 'team_align elementor%s-align-',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_2',[
                    'label'     => esc_html__('Singel Member Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                't_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .single-team' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 't_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .single-team',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 't_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .single-team',
                ]
        );
        $this->add_control(
            't_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .single-team' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_control(
                't_area_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .single-team' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                't_area_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .single-team' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Image Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_responsive_control(
            'img_width',
            [
                'label' => esc_html__( 'Width', 'nsstheme' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [],
                'selectors' => [
                    '{{WRAPPER}} .teahm-thumb img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'img_height',
            [
                'label' => esc_html__( 'Height', 'nsstheme' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [],
                'selectors' => [
                    '{{WRAPPER}} .teahm-thumb img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .teahm-thumb' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_5',[
                    'label'     => esc_html__('Name Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'f_1_title_color',[
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .team-details h5'  => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_control(
                'f_1_title_hover_color',[
                        'label' => esc_html__( 'Hove Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .team-details h5 a:hover'  => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name' => 'f_1_title_typography',
                        'label' => esc_html__( 'Typography', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .team-details h5',
                ]
        );
        $this->add_control(
                'f_1_title_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .team-details h5' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_6',[
                    'label'     => esc_html__('Designation Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'f_1_desgi_color',[
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .team-details p'  => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name' => 'f_1_desgi_typography',
                        'label' => esc_html__( 'Typography', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .team-details p',
                ]
        );
        $this->add_control(
                'f_1_desgi_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .team-details p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_07', [
                    'label'             => esc_html__('Social Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE
                ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'socail_typography',
                            'label' => esc_html__( 'Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .team-details ul li a',
                    ]
            );
            $this->add_control(
                    'socail_item_padding',
                    [
                            'label' => esc_html__( 'Item Padding', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .team-details ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                            ],
                    ]
            );
            $this->add_control(
                    'socail_item_margin',
                    [
                            'label' => esc_html__( 'Item Margin', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .team-details ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                            ],
                    ]
            );
            $this->add_responsive_control(
                's_width',
                [
                    'label' => esc_html__( 'Width', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .team-details ul li a' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                's_height',
                [
                    'label' => esc_html__( 'Height', 'nsstheme' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 1000,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [],
                    'selectors' => [
                        '{{WRAPPER}} .team-details ul li a' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->start_controls_tabs( 'item_styling_tab' );
                $this->start_controls_tab(
                        'item_styling_tab_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'socail_color',[
                                'label' => esc_html__( 'Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .team-details ul li a'  => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        's_item_bg',
                        [
                                'label' => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'  => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .team-details ul li a' => 'background: {{VALUE}}'
                                ],
                        ]
                );
            $this->end_controls_tab();
            $this->start_controls_tab(
                    'item_styling_tab_hover',
                    [
                            'label' => esc_html__( 'Hover', 'nsstheme' ),
                    ]
            );
            $this->add_control(
                    'socail_hover_color',[
                            'label' => esc_html__( 'Color', 'nsstheme' ),
                            'type' => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .team-details ul li a:hover'  => 'color: {{VALUE}}',
                            ],
                    ]
            );
            $this->add_control(
                    's_item_bg_hover',
                    [
                            'label' => esc_html__( 'BG Color', 'nsstheme' ),
                            'type'  => Controls_Manager::COLOR,
                            'selectors' => [
                                    '{{WRAPPER}} .team-details ul li a:hover' => 'background: {{VALUE}}'
                            ],
                    ]
            );
            $this->end_controls_tab();
            $this->end_controls_tabs();
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings    = $this->get_settings();
        $social_list = $settings['social_list'];
        $button_url  = $settings['team_link'];
        $is_link     = $settings['is_link'];
        
       
    ?>
         <!-- Single Team Start -->
         <div class="single-team">
            <div class="teahm-thumb">
                <?php if($settings['image']['url'] !=''): ?>
                   <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr__('Team','nsstheme'); ?>">
                <?php endif; ?>
            </div>
            <div class="team-details">
                <?php if($settings['name'] != ''): ?>
                <h5>
                    <?php if($is_link == 'yes'): ?><a target="<?php echo esc_attr( $button_url['is_external'] =='on'?'_blank':'_self' ); ?>"  href="<?php echo esc_url($button_url['url']) ?>" class="team-link"><?php endif; ?>
                        <?php echo esc_html($settings['name'] ); ?>
                    <?php if($is_link == 'yes'): ?></a><?php endif; ?>
                </h5>
                <?php endif; ?>
                <?php if($settings['designation'] != ''): ?>
                    <p>
                        <?php echo esc_html($settings['designation'] ); ?>
                    </p>
                <?php endif; ?>
                <ul>
                    <?php foreach($social_list as $item): ?>
                    <li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ) ?> ">
                        <?php 
                           $social_url = $item['link'];
                        ?>
                        <a target="<?php echo esc_attr( $social_url['is_external'] =='on'?'_blank':'_self' ); ?>"  href="<?php echo esc_url($social_url['url']) ?>">
                            <i class="<?php echo esc_attr($item['icons']); ?>"></i>
                        </a>
                    </li>
                 <?php endforeach; ?>
                </ul>
            </div>
        </div>
        <!-- Single Team End -->
         
        <?php
    }
    
    protected function _content_template() {

    }
    
}