<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Teampost extends Widget_Base{
    
    public function get_name() {
        return 'nss-teampost';
    }
    
    public function get_title() {
        return esc_html__( 'Team Post Type', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-post-list';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Team Post Type', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'teampost_item',
                [
                        'label'     => esc_html__( 'Number Of Item', 'nsstheme' ),
                        'type'      => Controls_Manager::NUMBER,
                        'min'       => 3,
                        'max'       => 100,
                        'step'      => 1,
                        'default'   => 6,
                ]
        );
        $this->add_control(
                'order_by',
                [
                        'label' => esc_html__( 'Order By', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'date',
                        'options' => [
                                'date'       => esc_html__( 'Date', 'nsstheme' ),
                                'title'      => esc_html__( 'Title', 'nsstheme' ),
                                'rand'       => esc_html__( 'Random', 'nsstheme' ),
                        ],
                ]
        );
        $this->add_control(
                'order',
                [
                        'label' => esc_html__( 'Order', 'nsstheme' ),
                        'type'  => Controls_Manager::SELECT,
                        'default' => 'desc',
                        'options' => [
                                'asc'       => esc_html__( 'Ascending', 'nsstheme' ),
                                'desc'      => esc_html__( 'Descending', 'nsstheme' ),
                        ],
                ]
        );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings           = $this->get_settings();
        $teampost_item     = (isset($settings['teampost_item']) && $settings['teampost_item'] > 0) ? $settings['teampost_item'] : 6;
        $order_by           = (isset($settings['order_by']) && $settings['order_by'] != '') ? $settings['order_by'] : 'date';
        $order              = (isset($settings['order']) && $settings['order'] != '') ? $settings['order'] : 'desc';
        $targs = array(
                'post_type'         => 'team',
                'post_status'       => 'publish',
                'posts_per_page'    => $teampost_item,
                'orderby'           => $order_by,
                'order'             => $order
        );
        ?>
        <div class="row">
                <?php        
                $targs = new \WP_Query($targs);
                if($targs->have_posts()) {
                        while($targs->have_posts()) : $targs->the_post();
                                $team_project_title ='';
                                $team_title = '';
                                $social_list = '';
                                if(defined('FW')) {
                                        $team_project_title = fw_get_db_post_option(get_the_ID(), 'team_name', '');
                                        $team_title = fw_get_db_post_option(get_the_ID(), 'team_title', '');
                                        $social_list = fw_get_db_post_option(get_the_ID(), 'team_social_list', '');
                                }
                                ?>                    
                                <div class="col-lg-4 col-sm-6">
                                        <div class="single-team s2team-item">
                                                <a href="<?php the_permalink(); ?>">
                                                        <?php if(has_post_thumbnail()): ?>
                                                        <div class="teahm-thumb">
                                                                <img src="<?php echo esc_url(habu_post_thumbnail(get_the_ID(), 170, 170)) ?>" alt="<?php echo get_the_title(); ?>">
                                                        </div>
                                                        <?php endif; ?>
                                                        <p><?php echo esc_html($team_title); ?></p>
                                                        <h5><?php echo esc_html($team_project_title); ?></h5>
                                                </a>
                                                <ul>
                                                        <?php 
                                                        if(is_array($social_list) || $social_list != ''):
                                                                foreach($social_list as $slist):     
                                                        ?>
                                                                <li>
                                                                        <a href="<?php echo esc_url($slist['team_social_url']) ?>">
                                                                                <i class="<?php echo esc_attr($slist['team_social_icon']['icon-class']); ?>"></i>
                                                                        </a>
                                                                </li>
                                                        <?php 
                                                                endforeach; 
                                                        endif; 
                                                        ?>
                                                </ul>       
                                        </div>
                                </div>                      
                                <?php
                        endwhile;
                        wp_reset_postdata(); 
                }
                ?>
        </div>
        <?php

    }
    
    protected function _content_template() {
        
    }
}