<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Testimonial extends Widget_Base{
    
    public function get_name() {
        return 'nss-testimonial';
    }
    public function get_title() {
        return esc_html__( 'Testimonial Slider', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label' => esc_html__( 'Testimonial Slider', 'nsstheme' ),
            ]
        );
        $this->add_control(
                    'testi_style',
                    [
                            'label'     => esc_html__( 'View Style', 'nsstheme' ),
                            'label_block' => true,
                            'type'      => Controls_Manager::SELECT,
                            'default'   => 1,
                            'options'   => [
                                    1                   => esc_html__( 'Style 01', 'nsstheme' ),
                                    2                   => esc_html__( 'Style 02', 'nsstheme' ),
                            ],
                    ]
            );
            $this->add_control(
                    'aver_title',
                    [
                            'label'         => esc_html__( 'Average Rating Title', 'nsstheme' ),
                            'type'          => Controls_Manager::TEXT,
                            'default'       => '',
                            'label_block'   => true,
                            'condition'     => [
                                'testi_style' => ['1'],
                            ],
                            'placeholder'   => esc_html__('insert Top Average Rating Rating Title', 'nsstheme')
                    ]
            );
            $this->add_control(
                    'aver_rating',
                    [
                            'label'         => esc_html__( 'Average Rating', 'nsstheme' ),
                            'type'          => Controls_Manager::TEXT,
                            'default'       => '',
                            'condition'     => [
                                'testi_style' => ['1'],
                            ],
                            'label_block'   => true,
                            'placeholder'   => esc_html__('insert Top Average Rating. Rating Out of 5.', 'nsstheme')
                    ]
            );
            $repeater = new \Elementor\Repeater();
                $repeater->add_control(
                        'quote',
                        [
                                'label'         => esc_html__( 'Testimonial Quote', 'nsstheme' ),
                                'type'          => Controls_Manager::TEXTAREA,
                                'default'       => '',
                                'label_block'   => true,
                                'placeholder'   => esc_html__('Insert your testimony quote text.', 'nsstheme')
                        ]
                );
                $repeater->add_control(
                        'author_rating',
                        [
                                'label'         => esc_html__( 'Author Ratings', 'nsstheme' ),
                                'type'          => Controls_Manager::TEXT,
                                'default'       => '',
                                'label_block'   => true,
                                'placeholder'   => esc_html__('insert author Rating. Rating Out of 5.', 'nsstheme')
                        ]
                );
                $repeater->add_control(
                        'qut_img',
                        [
                                'label'         => esc_html__( 'Author Image', 'nsstheme' ),
                                'type'          => Controls_Manager::MEDIA,
                                'description'   => esc_html__('Image size should be 65x65px.', 'nsstheme'),
                        ]
                );
                $repeater->add_control(
                        'title',
                        [
                                'label'         => esc_html__( 'Author Name', 'nsstheme' ),
                                'type'          => Controls_Manager::TEXT,
                                'default'       => '',
                                'label_block'   => true,
                                'placeholder'   => esc_html__('Author Name', 'nsstheme')
                        ]
                );
                $repeater->add_control(
                        'designation',
                        [
                                'label'         => esc_html__( 'Designation or Organization', 'nsstheme' ),
                                'type'          => Controls_Manager::TEXT,
                                'default'       => '',
                                'label_block'   => true,
                                'placeholder'   => esc_html__('Designation or Organization', 'nsstheme')
                        ]
                );
            $this->add_control(
                'testimony_list',
                [
                        'label'         => esc_html__( 'Testimonial Slider', 'nsstheme' ),
                        'type'          => Controls_Manager::REPEATER,
                        'fields'        => $repeater->get_controls(),
                        'default'       => [
                                [
                                        'qut_img'           => '',
                                        'title'             => '',
                                        'author_rating'     => '',
                                        'designation'       => '',
                                        'quote'             => '',

                                ],
                        ],
                        'title_field' => '{{{ title }}}',
                ]
            );
             $this->add_control(
                    'testi_items',
                    [
                            'label' => esc_html__( 'Testimonial Items', 'nsstheme' ),
                            'type' => Controls_Manager::NUMBER,
                            'min' => 1,
                            'max' => 10,
                            'step' => 1,
                            'default' => 3,
                            'description'       => esc_html__('Choose how many items you want to show.', 'nsstheme'),
                    ]
            );
            $this->add_control(
                    'testi_slide_autoplay',
                    [
                            'label'             => esc_html__( 'Is Autoplay?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to make this slider auto play?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
            $this->add_control(
                    'testi_slide_loop',
                    [
                            'label'             => esc_html__( 'Is Loop?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to make this slider item loop?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
            $this->add_control(
                    'testi_slide_nav',
                    [
                            'label'             => esc_html__( 'Is Nav?', 'nsstheme' ),
                            'type'              => Controls_Manager::SWITCHER,
                            'label_on'          => esc_html__( 'Yes', 'nsstheme' ),
                            'label_off'         => esc_html__( 'No', 'nsstheme' ),
                            'description'       => esc_html__('Do you want to show slider arrow navigation?', 'nsstheme'),
                            'return_value'      => 'yes',
                            'default'           => 'yes',
                    ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_testimonial', [
                    'label'             => esc_html__('Single Testimonial', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['1'],
                    ],
                ]
        );
        $this->add_control(
                'cl_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'cl_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .testimonial_item',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'cl_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .testimonial_item',
                ]
        );
        $this->add_control(
            'box_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .testimonial_item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_responsive_control(
                'post_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'post_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_testimonial_two', [
                    'label'             => esc_html__('Single Testimonial', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['2'],
                    ],
                ]
        );
        $this->add_control(
                'cl_item_bg_two',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item_two' => 'background: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'cl_item_shadow_two',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .testimonial_item_two',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'cl_item_border_two',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .testimonial_item_two',
                ]
        );
        $this->add_control(
            'box_border_radius_two',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .testimonial_item_two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_responsive_control(
                'post_padding_two',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item_two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'post_margin_two',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item_two' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_02', [
                    'label'             => esc_html__('Quote Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'tst_qt_color',
                [
                        'label' => esc_html__( 'Text Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item p' => 'color: {{VALUE}}',
                                '{{WRAPPER}} .testimonial_item_two p' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'tst_qt_typo',
                        'label'     => esc_html__( 'Text Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item p',
                        'condition'         => [
                            'testi_style'   => ['1'],
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'tst_two_qt_typo',
                        'label'     => esc_html__( 'Text Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item_two p',
                        'condition'         => [
                            'testi_style'   => ['2'],
                        ],
                ]
        );
        $this->add_control(
                'tst_qt_margin',
                [
                        'label' => esc_html__( 'Text Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                '{{WRAPPER}} .testimonial_item_two p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Quote Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .testimonial_item p:before',
                        'condition'         => [
                            'testi_style'   => ['1'],
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_two_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .testimonial_item_two:after',
                        'condition'         => [
                            'testi_style'   => ['2'],
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'tst_icon_top_typo',
                        'label'     => esc_html__( 'Quote Icon Top Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item p:before',
                        'condition'         => [
                            'testi_style'   => ['1'],
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'tst_icon_bottom_typo',
                        'label'     => esc_html__( 'Quote Icon Bottom Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item:after',
                        'condition'         => [
                            'testi_style'   => ['1'],
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'tst_icon_typo',
                        'label'     => esc_html__( 'Quote Icon Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item_two:after',
                        'condition'         => [
                            'testi_style'   => ['2'],
                        ],
                ]
        );
        $this->add_control(
                'tst_icon_margin',
                [
                        'label' => esc_html__( 'Quote Icon Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item p:after' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                '{{WRAPPER}} .testimonial_item p:before' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                '{{WRAPPER}} .testimonial_item_two:after' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_03', [
                    'label'             => esc_html__('Ratings Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['1'],
                    ],
                ]
        );
        $this->add_control(
                'rating_text_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item .av-rate-box' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_control(
                'rating_icon_color',
                [
                        'label' => esc_html__( 'Rating Icon Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item .av-rate-box i' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'rating_bg_color',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item .av-rate-box' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'rating_text_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item .av-rate-box',
                ]
        );
        $this->add_control(
            'rating_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .testimonial_item .av-rate-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_responsive_control(
                'rating_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item .av-rate-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'rating_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item .av-rate-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_03_rate', [
                    'label'             => esc_html__('Ratings Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['2'],
                    ],
                ]
        );
        $this->add_control(
                'r_icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'r_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .testimonial_item_two .av-rate-box i',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'rating_rate_text_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testimonial_item_two .av-rate-box i',
                ]
        );
        $this->add_control(
                'rating_rate_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_item_two .av-rate-box i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_04', [
                    'label'             => esc_html__('Author Area Style', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['1'],
                    ],
                ]
        );
        $this->add_control(
                'author_area_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testi-author' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_responsive_control(
                'author_area_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testi-author' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_responsive_control(
                'author_area_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testi-author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_05_author', [
                    'label'             => esc_html__('Author Image Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['2'],
                    ],
                ]
        );
        $this->add_control(
                'tst_two_img_width',
                [
                        'label' => esc_html__( 'Width', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 20,
                                        'max' => 400,
                                        'step' => 5,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img' => 'width: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'tst_two_img_height',
                [
                        'label' => esc_html__( 'Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 20,
                                        'max' => 400,
                                        'step' => 5,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'tst_two_img_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img',
                ]
        );
        $this->add_control(
            'tst_two_img_radius',
            [
                    'label'      => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'       => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors'  => [
                            '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img img'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
            ]
        );
        $this->add_control(
                'tst_two_img_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'tst_two_img_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_05', [
                    'label'             => esc_html__('Author Image Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                    'condition'         => [
                        'testi_style'   => ['1'],
                    ],
                ]
        );
        $this->add_control(
                'author_img_bg_color',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider_two.owl-carousel .testi_img' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_control(
                'tst_img_width',
                [
                        'label' => esc_html__( 'Width', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 20,
                                        'max' => 400,
                                        'step' => 5,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider.owl-carousel img' => 'width: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'tst_img_height',
                [
                        'label' => esc_html__( 'Height', 'nsstheme' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px'],
                        'range' => [
                                'px' => [
                                        'min' => 20,
                                        'max' => 400,
                                        'step' => 5,
                                ]
                        ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider.owl-carousel img' => 'height: {{SIZE}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
            'tst_img_radius',
            [
                    'label'      => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'       => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors'  => [
                            '{{WRAPPER}} .testimonial_slider.owl-carousel img'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
            ]
        );
        $this->add_control(
                'tst_img_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testimonial_slider.owl-carousel img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_06', [
                    'label'             => esc_html__('Author Meta Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'author_name_options',
                [
                        'label'     => esc_html__( 'Author Name Style', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_control(
                'author_name_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testi-author h5' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'author_name_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testi-author h5',
                ]
        );
        $this->add_control(
                'author_name_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testi-author h5' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->add_control(
                'author_designation_options',
                [
                        'label'     => esc_html__( 'Author Designation Style', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_control(
                'author_designation_color',
                [
                        'label' => esc_html__( 'Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .testi-author span' => 'color: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'author_designation_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .testi-author span',
                ]
        );
        $this->add_control(
                'author_designation_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .testi-author span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_07', [
                    'label'             => esc_html__('Nav Styling', 'nsstheme'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
        );
            $this->start_controls_tabs( 'nav_styling_tab' );
                $this->start_controls_tab(
                        'nav_styling_tab_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                    $this->add_control(
                            'tst_nav_color',
                            [
                                    'label' => esc_html__( 'Nav Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button' => 'color: {{VALUE}}',
                                    ],
                            ]
                    );
                    $this->add_control(
                            'tst_nav_bg',
                            [
                                    'label' => esc_html__( 'Nav BG Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button' => 'background: {{VALUE}}'
                                    ],
                            ]
                    );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'nav_styling_tab_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                    $this->add_control(
                            'tst_nav_color_hover',
                            [
                                    'label' => esc_html__( 'Nav Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button:hover' => 'color: {{VALUE}}'
                                    ],
                            ]
                    );
                    $this->add_control(
                            'tst_nav_bg_hover',
                            [
                                    'label' => esc_html__( 'Nav BG Color', 'nsstheme' ),
                                    'type'  => Controls_Manager::COLOR,
                                    'selectors' => [
                                            '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button:hover:after' => 'background: {{VALUE}}'
                                    ],
                            ]
                    );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_group_control(
                    Group_Control_Box_Shadow::get_type(),
                    [
                            'name' => 'tst_nav_bg_shadow',
                            'label' => esc_html__( 'Boxs Shadow', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button',
                    ]
            );
            $this->add_group_control(
                    Group_Control_Border::get_type(),
                    [
                            'name' => 'tst_nav_bg_border',
                            'label' => esc_html__( 'Border', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button',
                    ]
            );
            $this->add_control(
                    'nav_width',
                    [
                            'label' => esc_html__( 'Nav Width', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px'],
                            'range' => [
                                    'px' => [
                                            'min' => 0,
                                            'max' => 500,
                                            'step' => 1,
                                    ]
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button' => 'width: {{SIZE}}{{UNIT}};'
                            ],
                    ]
            );
            $this->add_control(
                    'nav_height',
                    [
                            'label' => esc_html__( 'Nav Height', 'nsstheme' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px'],
                            'range' => [
                                    'px' => [
                                            'min' => 0,
                                            'max' => 500,
                                            'step' => 1,
                                    ]
                            ],
                            'selectors' => [
                                    '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button' => 'height: {{SIZE}}{{UNIT}};'
                            ],
                    ]
            );
            $this->add_control(
                    'nav_margin',
                    [
                            'label' => esc_html__( 'Nav Margins', 'nsstheme' ),
                            'type'  => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                    '{{WRAPPER}} .testi_wrap .owl-carousel .owl-nav button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                            ],
                    ]
            );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings       = $this->get_settings();

        $slider_style   = (isset($settings['testi_style']) && $settings['testi_style'] > 0) ? $settings['testi_style'] : 1;

        $aver_title     = $settings['aver_title'];
        $aver_rating    = $settings['aver_rating'];

        $testi_list    = (isset($settings['testimony_list']) && !empty($settings['testimony_list'])) ? $settings['testimony_list'] : array();
        
        $autoplay = (isset($settings['testi_slide_autoplay']) && $settings['testi_slide_autoplay'] != '' ? $settings['testi_slide_autoplay'] : 'yes');
        $testi_items = (isset($settings['testi_items']) && $settings['testi_items'] != '' ? $settings['testi_items'] : 3);
        $loop = (isset($settings['testi_slide_loop']) && $settings['testi_slide_loop'] != '' ? $settings['testi_slide_loop'] : 'yes');
        $nav = (isset($settings['testi_slide_nav']) ? $settings['testi_slide_nav'] : 'yes');
        

        include dirname(__FILE__).'/style/testimonial/style'.$slider_style.'.php';

    }
        
    protected function _content_template() {

    }
}