<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )
    exit;

class NSS_Vacancy_Widgets extends Widget_Base {

    public function get_name() {
        return 'nss-vacancy';
    }

    public function get_title() {
        return esc_html__( 'Job Vacancy', 'nsstheme' );
    }

    public function get_icon() {
        return 'eicon-post-info';
    }

    public function get_categories() {
        return [ 'habu-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab_1', [
                'label'     => esc_html__( 'Vacancy', 'nsstheme' ),
            ]
        );
        $this->add_control(
                'p_icons',
                [
                        'label'         => esc_html__( 'Vacancy Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $this->add_control(
                'vacancy_number',
                [
                        'label'         => esc_html__( 'Vacancy Number', 'nsstheme' ),
                        'type'          => Controls_Manager::TEXT,
                        'default'       => '12',
                        'label_block'   => TRUE,
                        'placeholder'   => esc_html__('Vacancy Number', 'nsstheme'),
                ]
        );
        $this->add_control(
            'title', [
                'label'       => esc_html__( 'Vacancy Title', 'nsstheme' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__( 'title here', 'nsstheme' ),
                'default'     => esc_html__( 'Web Developer', 'nsstheme' ),
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
                'icons',
                [
                        'label'         => esc_html__( 'Job Icon', 'nsstheme' ),
                        'type'          => Controls_Manager::ICON,
                        'label_block'   => TRUE,
                ]
        );
        $repeater->add_control(
            'j_title', [
                'label'         => esc_html__( 'Job Title', 'nsstheme' ),
                'type'		=> Controls_Manager::TEXTAREA,
                'label_block'	=> true,
                'placeholder'	=> esc_html__( 'Add Title', 'nsstheme' ),
                'default'	=> '',
            ]
        );
        $repeater->add_control(
            'description', [
                'label'         => esc_html__( 'Job Description', 'nsstheme' ),
                'type'      => Controls_Manager::TEXTAREA,
                'label_block'   => true,
                'placeholder'   => esc_html__( 'Add Description', 'nsstheme' ),
                'default'   => '',
            ]
        );
         $repeater->add_control(
               'btn_label', [
                  'label'       => esc_html__( 'Btn Label', 'nsstheme' ),
                  'type'        => Controls_Manager::TEXT,
                  'default'     => esc_html__( 'Apply Now' , 'nsstheme' ),
                  'label_block' => true,
               ]
            );
            $repeater->add_control(
                'btn_url', [
                   'label'          => esc_html__( 'Url', 'nsstheme' ),
                   'type'           => Controls_Manager::TEXT,
                   'default'        => esc_html__( '#' , 'nsstheme' ),
                   'label_block'    => true,
                ]
             );
        $this->add_control(
            'list',
            [
                    'label'         => esc_html__( 'Description Item', 'nsstheme' ),
                    'type'          => Controls_Manager::REPEATER,
                    'fields'        => $repeater->get_controls(),
                    'default'       => [
                            [
                                    'j_title'         => esc_html__( '', 'nsstheme' ),
                                    'description'     => esc_html__( '', 'nsstheme' ),
                                    'icons'           => esc_html__( '', 'nsstheme' ),
                                    'btn_label'       => esc_html__( '', 'nsstheme' ),
                                    'btn_url'         => esc_html__( '', 'nsstheme' ),

                            ],
                    ],
                    'title_field' => '{{{ j_title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_2',[
                    'label'     => esc_html__('Vacancy Area Style', 'nsstheme'),
                    'tab'       => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'p_item_bg',
                [
                        'label' => esc_html__( 'BG Color', 'nsstheme' ),
                        'type'  => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item' => 'background: {{VALUE}}'
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                        'name' => 'p_item_shadow',
                        'label' => esc_html__( 'Box Shadow', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .vacancy-item',
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'p_item_border',
                        'label' => esc_html__( 'Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .vacancy-item',
                ]
        );
        $this->add_control(
            'p_border_radius',
            [
                    'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                    'type'  => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                            '{{WRAPPER}} .vacancy-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
            ]
        );
        $this->add_control(
                'p_area_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'p_area_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'  => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_3',[
                    'label'         => esc_html__('Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_i_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .vacancy-top i',
                ]
        );
        $this->add_responsive_control(
                'icon_box_i_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-top i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'icon_box_i_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .vacancy-top i',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_number',[
                    'label'         => esc_html__('Vacancy Number Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'vacancy_number_color',[
                        'label'     => esc_html__( 'Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-top p' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'vacancy_number_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .vacancy-top p',
                ]
        );
        $this->add_control(
                'vacancy_number_pading',
                [
                        'label'      => esc_html__( 'Padding', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-top p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'vacancy_number_margin',
                [
                        'label'      => esc_html__( 'Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-top p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_4',[
                    'label'         => esc_html__('Title Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'icon_box_title_color',[
                        'label'     => esc_html__( 'Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item h4' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'icon_box_title_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .vacancy-item h4',
                ]
        );
        $this->add_control(
                'icon_box_title_pading',
                [
                        'label'      => esc_html__( 'Padding', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-item h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'icon_box_title_margin',
                [
                        'label'      => esc_html__( 'Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-item h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
                'section_tab_5',[
                    'label'         => esc_html__('Description Icon Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'desc_icon_typography',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .vacancy-item ul li i',
                ]
        );
        $this->add_responsive_control(
                'desc_icon_margin',
                [
                        'label' => esc_html__( 'Margins', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item ul li i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                ]
        );
        $this->add_control(
                'desc_icon_options',
                [
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'type'      => Controls_Manager::HEADING,
                        'separator' => 'before',
                ]
        );
        $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                        'name'      => 'desc_icon_color',
                        'label'     => esc_html__( 'Icon Color', 'nsstheme' ),
                        'types'     => ['gradient'],
                        'selector'  => '{{WRAPPER}} .vacancy-item ul li i',
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
                'section_tab_6',[
                    'label'         => esc_html__('Description Style', 'nsstheme'),
                    'tab'           => Controls_Manager::TAB_STYLE
                ]
        );
        $this->add_control(
                'desc_color',[
                        'label'     => esc_html__( 'Color', 'nsstheme' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item ul li' => 'color: {{VALUE}}',
                        ],
                ]
        );
        $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                        'name' => 'desc_border',
                        'label' => esc_html__( 'Description Border', 'nsstheme' ),
                        'selector' => '{{WRAPPER}} .vacancy-item ul li',
                ]
        );
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                        'name'      => 'desc_typo',
                        'label'     => esc_html__( 'Typography', 'nsstheme' ),
                        'selector'  => '{{WRAPPER}} .vacancy-item ul li',
                ]
        );
        $this->add_control(
                'desc_margin',
                [
                        'label'      => esc_html__( 'Margin', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-item ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->add_control(
                'desc_padding',
                [
                        'label'      => esc_html__( 'Paddings', 'nsstheme' ),
                        'type'       => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors'  => [
                                '{{WRAPPER}} .vacancy-item ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
        );
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_tab_button',
            [
                'label'         => esc_html__('Button Style', 'nsstheme'),
                'tab'           => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs( 'style_tabs_1' );
                $this->start_controls_tab(
                        'btn_1_button_style_normal',
                        [
                                'label' => esc_html__( 'Normal', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_1_label_color',
                        [
                                'label' => esc_html__( 'Label Color', 'nsstheme' ),
                                'type' => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .vacancy-item .habu-btn'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_bg',
                        [
                                'label'     => esc_html__( 'BG Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .vacancy-item .habu-btn'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
                $this->start_controls_tab(
                        'btn_1_button_style_hover',
                        [
                                'label' => esc_html__( 'Hover', 'nsstheme' ),
                        ]
                );
                $this->add_control(
                        'btn_label_hover_color',
                        [
                                'label'     => esc_html__( 'Label Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .vacancy-item .habu-btn:hover'   => 'color: {{VALUE}}',
                                ],
                        ]
                );
                $this->add_control(
                        'btn_1_hover_bg',
                        [
                                'label'     => esc_html__( 'BG Hover Color', 'nsstheme' ),
                                'type'      => Controls_Manager::COLOR,
                                'selectors' => [
                                        '{{WRAPPER}} .vacancy-item .habu-btn:after'   => 'background: {{VALUE}}',
                                ],
                        ]
                );
                $this->end_controls_tab();
            $this->end_controls_tabs();
            $this->add_control(
            'btn_1_width',
            [
                'label' => esc_html__( 'Width', 'nsstheme' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [],
                'selectors' => [
                    '{{WRAPPER}} .vacancy-item .habu-btn' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'btn_1_height',
            [
                'label' => esc_html__( 'Height', 'nsstheme' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [],
                'selectors' => [
                    '{{WRAPPER}} .vacancy-item .habu-btn' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
            $this->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                            'name' => 'btn_1_typography',
                            'label' => esc_html__( 'Button Typography', 'nsstheme' ),
                            'selector' => '{{WRAPPER}} .vacancy-item .habu-btn',
                    ]
            );
            $this->add_control(
                'border_radius',
                [
                        'label' => esc_html__( 'Border Radius', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item .habu-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                                '{{WRAPPER}} .vacancy-item .habu-btn:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_padding',
                [
                        'label' => esc_html__( 'Paddings', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item .habu-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
            $this->add_control(
                'btn_1_margin',
                [
                        'label' => esc_html__( 'Margin', 'nsstheme' ),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => [ 'px', '%', 'em' ],
                        'selectors' => [
                                '{{WRAPPER}} .vacancy-item .habu-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ],
                ]
            );
        $this->end_controls_section();
        
    }

    protected function render() {
        $settings       = $this->get_settings();
        $p_icons        = $settings['p_icons'];
        $vacancy_number = $settings['vacancy_number'];
        $title          = $settings['title'];
        $list           = (isset($settings['list']) && !empty($settings['list'])) ? $settings['list'] : array();
        
        ?>

        <div class="vacancy-item">
            <div class="vacancy-top">
                <?php if($p_icons != ''): ?>
                    <i class="<?php echo esc_attr($p_icons); ?>"></i>
                <?php endif; ?>
                <?php if($vacancy_number != ''): ?>
                    <p><?php echo esc_html__('Vacancy - ', 'nsstheme') ?><span><?php echo esc_html($vacancy_number); ?></span></p>
                <?php endif; ?>
            </div>
            <?php if($title != ''): ?>
                <h4><?php echo esc_html($title); ?></h4>
            <?php endif; ?>
            <?php if(count($list) > 0): ?>
                <ul>
                    <?php 
                    $i = 1; 
                    foreach ($list as $item):
                        $icons          = (isset($item['icons'])) ? $item['icons'] : '';
                        $j_title        = (isset($item['j_title'])) ? $item['j_title'] : '';
                        $description    = (isset($item['description'])) ? $item['description'] : '';
                        $btn_label      = (isset($item['btn_label'])) ? $item['btn_label'] : '';
                        $btn_url        = (isset($item['btn_url'])) ? $item['btn_url'] : '';
                    ?>
                    <li>
                        <?php if($icons != ''): ?>
                            <i class="<?php echo esc_attr($icons); ?>"></i>
                        <?php endif; ?>
                        <?php if($j_title != ''): 
                            echo habu_kses($j_title);
                         endif;
                         ?>
                        <?php if($description != ''): ?>
                             <span><?php echo habu_kses($description); ?></span>
                         <?php endif;?>
                        <?php if($btn_label != ''): ?>
                            <a class="habu-btn" href="<?php echo esc_url($btn_url); ?>"><span><?php echo esc_html($btn_label); ?></span></a>
                        <?php endif; ?>
                    </li>
                    <?php 
                    $i++;
                    endforeach;
                    ?>
                </ul>
            <?php endif; ?>
        </div><?php
    }

    protected function _content_template() {

    }
}
